/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Icon } from "../definitions/Icon";
import { GlobalSpaceIdentifier } from "../definitions/GlobalSpaceIdentifier";
import { SpaceDescription } from "../definitions/SpaceDescription";
import { Content } from "../definitions/Content";
import { LabelArray } from "../definitions/LabelArray";
import { OperationCheckResult } from "../definitions/OperationCheckResult";
import { SpacePermission } from "../definitions/SpacePermission";
import { SpaceSettings } from "../definitions/SpaceSettings";
import { Theme } from "../definitions/Theme";
import { LookAndFeel } from "../definitions/LookAndFeel";
import { User } from "../definitions/User";
import { ContentBodyCreate } from "../definitions/ContentBodyCreate";
export interface ContentCreate {
    /**
     * The ID of the draft content. Required when publishing a draft.
     */
    id?: string;
    title?: string;
    /**
     * The type of the new content. Custom content types defined by apps are also supported. eg. 'page', 'blogpost', 'comment' etc.
     */
    type: string;
    /**
     * The space that the content is being created in.
     */
    space?: {
        id?: number;
        name?: string;
        icon?: Icon;
        identifiers?: GlobalSpaceIdentifier;
        description?: {
            plain?: SpaceDescription;
            view?: SpaceDescription;
            _expandable?: {
                view?: string;
                plain?: string;
            };
        };
        homepage?: Content;
        type?: string;
        metadata?: {
            labels?: LabelArray;
            _expandable?: any;
        };
        operations?: Array<OperationCheckResult>;
        permissions?: Array<SpacePermission>;
        status?: string;
        settings?: SpaceSettings;
        theme?: Theme;
        lookAndFeel?: LookAndFeel;
        history?: {
            createdDate: string;
            createdBy?: User;
        };
        /**
         * The key of the space.
         */
        key: string;
        links?: {
            [x: string]: any;
        };
    };
    /**
     * The status of the new content.
     */
    status?: "current" | "deleted" | "historical" | "draft";
    /**
  * The container of the content. Required if type is `comment` or certain types of
  custom content. If you are trying to create a comment that is a child of another comment,
  specify the parent comment in the ancestors field, not in this field.
  */
    container?: {
        /**
         * The `id` of the container.
         */
        id: number | string;
        /**
         * The `type` of the container.
         */
        type: string;
        [x: string]: any;
    };
    /**
  * The parent content of the new content.  If you are creating a top-level `page` or `comment`,
  this can be left blank. If you are creating a child page, this is where the parent page id goes.
  If you are creating a child comment, this is where the parent comment id goes. Only one parent
  content id can be specified.
  */
    ancestors?: Array<{
        /**
         * The `id` of the parent content.
         */
        id: string;
        [x: string]: any;
    }>;
    /**
  * The body of the new content. Does not apply to attachments.
  Only one body format should be specified as the property for
  this object, e.g. `storage`.
  
  Note, `editor2` format is used by Atlassian only. `anonymous_export_view` is
  the same as `export_view` format but only content viewable by an anonymous
  user is included.
  */
    body?: {
        view?: ContentBodyCreate;
        export_view?: ContentBodyCreate;
        styled_view?: ContentBodyCreate;
        storage?: ContentBodyCreate;
        editor?: ContentBodyCreate;
        editor2?: ContentBodyCreate;
        wiki?: ContentBodyCreate;
        anonymous_export_view?: ContentBodyCreate;
        plain?: ContentBodyCreate;
        atlas_doc_format?: ContentBodyCreate;
        raw?: ContentBodyCreate;
    };
    [x: string]: any;
}
//# sourceMappingURL=ContentCreate.d.ts.map