/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentBodyCreate } from "../definitions/ContentBodyCreate";
import { ContentBodyCreateStorage } from "../definitions/ContentBodyCreateStorage";
export interface ContentUpdate {
    /**
  * The new version for the updated content. Set this to the current version number incremented by one, unless you are changing the status to 'draft' which must have a version number of 1.
  
  To get the current version number, use [Get content by ID](#api-content-id-get) and retrieve `version.number`.
  */
    version: {
        /**
         * The version number.
         */
        number: number;
        /**
         * An optional message to be stored with the corresponding version.
         */
        message?: string;
        [x: string]: any;
    };
    /**
     * The updated title of the content. If you are updating a non-draft `page` or `blogpost`, title is required. If you are not changing the title, set this field to the the current title.
     */
    title?: string;
    /**
     * The type of content. Set this to the current type of the content. For example, - page - blogpost - comment - attachment
     */
    type: string;
    /**
  * The updated status of the content. Note, if you change the status of a page from
  'current' to 'draft' and it has an existing draft, the existing draft will be deleted
  in favor of the updated page.
  */
    status?: "current" | "trashed" | "deleted" | "historical" | "draft";
    /**
     * The new parent for the content. Only one parent content 'id' can be specified.
     */
    ancestors?: Array<{
        /**
         * The `id` of the parent content.
         */
        id: number | string;
        [x: string]: any;
    }>;
    /**
  * The updated body of the content. Does not apply to attachments.
  If you are not sure how to generate these formats, you can create a page in the
  Confluence application, retrieve the content using [Get content](#api-content-get),
  and expand the desired content format, e.g. `expand=body.storage`.
  */
    body?: {
        view?: ContentBodyCreate;
        export_view?: ContentBodyCreate;
        styled_view?: ContentBodyCreate;
        storage?: ContentBodyCreateStorage;
        editor?: ContentBodyCreate;
        editor2?: ContentBodyCreate;
        wiki?: ContentBodyCreate;
        atlas_doc_format?: ContentBodyCreate;
        anonymous_export_view?: ContentBodyCreate;
    };
    [x: string]: any;
}
//# sourceMappingURL=ContentUpdate.d.ts.map