/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GenericAccountId } from "../definitions/GenericAccountId";
import { Icon } from "../definitions/Icon";
import { OperationCheckResult } from "../definitions/OperationCheckResult";
import { UserDetails } from "../definitions/UserDetails";
import { Space } from "../definitions/Space";
import { GenericLinks } from "../definitions/GenericLinks";
export interface User {
    type: "known" | "unknown" | "anonymous" | "user";
    accountId?: GenericAccountId;
    /**
     * The account type of the user, may return empty string if unavailable. App is if the user is a bot user created on behalf of an Atlassian app.
     */
    accountType?: "atlassian" | "app" | "";
    /**
     * The email address of the user. Depending on the user's privacy setting, this may return an empty string.
     */
    email?: string;
    /**
     * The public name or nickname of the user. Will always contain a value.
     */
    publicName?: string;
    profilePicture?: Icon;
    /**
     * The displays name of the user. Depending on the user's privacy setting, this may be the same as publicName.
     */
    displayName?: string;
    /**
     * This displays user time zone. Depending on the user's privacy setting, this may return null.
     */
    timeZone?: string;
    /**
     * This is deprecated. Use `isGuest` instead to find out whether the user is a guest user.
     */
    externalCollaborator?: boolean;
    /**
     * This is deprecated. Use `isGuest` instead to find out whether the user is a guest user.
     */
    isExternalCollaborator?: boolean;
    /**
     * Whether the user is a guest user
     */
    isGuest?: boolean;
    operations?: Array<OperationCheckResult>;
    details?: UserDetails;
    personalSpace?: Space;
    _expandable?: {
        operations?: string;
        details?: string;
        personalSpace?: string;
    };
    _links?: GenericLinks;
    [x: string]: any;
}
//# sourceMappingURL=User.d.ts.map