/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GenericAccountIdAsResponse } from "../definitions/GenericAccountIdAsResponse";
import { IconAsResponse } from "../definitions/IconAsResponse";
import { OperationCheckResultAsResponse } from "../definitions/OperationCheckResultAsResponse";
import { UserDetailsAsResponse } from "../definitions/UserDetailsAsResponse";
import { SpaceAsResponse } from "../definitions/SpaceAsResponse";
import { GenericLinksAsResponse } from "../definitions/GenericLinksAsResponse";
export interface UserAsResponse {
    type: "known" | "unknown" | "anonymous" | "user";
    accountId?: GenericAccountIdAsResponse;
    /**
     * The account type of the user, may return empty string if unavailable. App is if the user is a bot user created on behalf of an Atlassian app.
     */
    accountType?: "atlassian" | "app" | "";
    /**
     * The email address of the user. Depending on the user's privacy setting, this may return an empty string.
     */
    email?: string;
    /**
     * The public name or nickname of the user. Will always contain a value.
     */
    publicName?: string;
    profilePicture?: IconAsResponse;
    /**
     * The displays name of the user. Depending on the user's privacy setting, this may be the same as publicName.
     */
    displayName?: string;
    /**
     * This displays user time zone. Depending on the user's privacy setting, this may return null.
     */
    timeZone?: string;
    /**
     * This is deprecated. Use `isGuest` instead to find out whether the user is a guest user.
     */
    externalCollaborator?: boolean;
    /**
     * This is deprecated. Use `isGuest` instead to find out whether the user is a guest user.
     */
    isExternalCollaborator?: boolean;
    /**
     * Whether the user is a guest user
     */
    isGuest?: boolean;
    operations?: Array<OperationCheckResultAsResponse>;
    details?: UserDetailsAsResponse;
    personalSpace?: SpaceAsResponse;
    _expandable?: {
        operations?: string;
        details?: string;
        personalSpace?: string;
    };
    _links?: GenericLinksAsResponse;
    [x: string]: any;
}
//# sourceMappingURL=UserAsResponse.d.ts.map