/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentBodyCreate } from "../../definitions/ContentBodyCreate";
import { ContentBodyAsResponse } from "../../definitions/ContentBodyAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { AsyncIdAsResponse } from "../../definitions/AsyncIdAsResponse";
import { AsyncContentBodyAsResponse } from "../../definitions/AsyncContentBodyAsResponse";
export interface ConvertContentBodyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the target format for the content body.
     */
    to: string;
    /**
  * The space key used for resolving embedded content (page includes,
  files, and links) in the content body. For example, if the source content
  contains the link `<ac:link><ri:page ri:content-title="Example page" /><ac:link>`
  and the `spaceKeyContext=TEST` parameter is provided, then the link
  will be converted to a link to the "Example page" page in the "TEST" space.
  */
    spaceKeyContext?: string;
    /**
  * The content ID used to find the space for resolving embedded content
  (page includes, files, and links) in the content body. For example,
  if the source content contains the link `<ac:link><ri:page ri:content-title="Example page" /><ac:link>`
  and the `contentIdContext=123` parameter is provided, then the link
  will be converted to a link to the "Example page" page in the same space
  that has the content with ID=123. Note, `spaceKeyContext` will be ignored
  if this parameter is provided.
  */
    contentIdContext?: string;
    /**
  * Mode used for rendering embedded content, like attachments.
  
  - `current` renders the embedded content using the latest version.
  - `version-at-save` renders the embedded content using the version at
  the time of save.
  */
    embeddedContentRender?: "current" | "version-at-save";
    /**
  * A multi-value parameter indicating which properties of the content to expand and populate. Expands are dependent on the
  `to` conversion format and may be irrelevant for certain conversions (e.g. `macroRenderedOutput` is redundant when
  converting to `view` format).
  
  If rendering to `view` format, and the body content being converted includes arbitrary nested content (such as macros); then it is
  necessary to include webresource expands in the request. Webresources for content body are the batched JS and CSS dependencies for
  any nested dynamic content (i.e. macros).
  
  - `embeddedContent` returns metadata for nested content (e.g. page included using page include macro)
  - `mediaToken` returns JWT token for retrieving attachment data from Media API
  - `macroRenderedOutput` additionally converts body to view format
  - `webresource.superbatch.uris.js` returns all common JS dependencies as static URLs
  - `webresource.superbatch.uris.css` returns all common CSS dependencies as static URLs
  - `webresource.superbatch.uris.all` returns all common dependencies as static URLs
  - `webresource.superbatch.tags.all` returns all common JS dependencies as html `<script>` tags
  - `webresource.superbatch.tags.css` returns all common CSS dependencies as html `<style>` tags
  - `webresource.superbatch.tags.js` returns all common dependencies as html `<script>` and `<style>` tags
  - `webresource.uris.js` returns JS dependencies specific to conversion
  - `webresource.uris.css` returns CSS dependencies specific to conversion
  - `webresource.uris.all` returns all dependencies specific to conversion
  - `webresource.tags.all` returns common JS dependencies as html `<script>` tags
  - `webresource.tags.css` returns common CSS dependencies as html `<style>` tags
  - `webresource.tags.js` returns common dependencies as html `<script>` and `<style>` tags
  */
    expand?: Array<string>;
    body: ContentBodyCreate;
}
declare type ConvertContentBodyResponseOKType = ContentBodyAsResponse;
export interface ConvertContentBodyResponseOK extends ConvertContentBodyResponseOKType {
}
export declare type ConvertContentBodyResponseError = undefined;
export interface AsyncConvertContentBodyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the target format for the content body.
     */
    to: "export_view" | "editor" | "storage" | "styled_view" | "view" | "atlas_doc_format";
    /**
  * A multi-value parameter indicating which properties of the content to expand and populate. Expands are dependent on the
  `to` conversion format and may be irrelevant for certain conversions (e.g. `macroRenderedOutput` is redundant when
  converting to `view` format).
  
  If rendering to `view` format, and the body content being converted includes arbitrary nested content (such as macros); then it is
  necessary to include webresource expands in the request. Webresources for content body are the batched JS and CSS dependencies for
  any nested dynamic content (i.e. macros).
  
  - `embeddedContent` returns metadata for nested content (e.g. page included using page include macro)
  - `mediaToken` returns JWT token for retrieving attachment data from Media API
  - `macroRenderedOutput` additionally converts body to view format
  - `webresource.superbatch.uris.js` returns all common JS dependencies as static URLs
  - `webresource.superbatch.uris.css` returns all common CSS dependencies as static URLs
  - `webresource.superbatch.uris.all` returns all common dependencies as static URLs
  - `webresource.superbatch.tags.all` returns all common JS dependencies as html `<script>` tags
  - `webresource.superbatch.tags.css` returns all common CSS dependencies as html `<style>` tags
  - `webresource.superbatch.tags.js` returns all common dependencies as html `<script>` and `<style>` tags
  - `webresource.uris.js` returns JS dependencies specific to conversion
  - `webresource.uris.css` returns CSS dependencies specific to conversion
  - `webresource.uris.all` returns all dependencies specific to conversion
  - `webresource.tags.all` returns common JS dependencies as html `<script>` tags
  - `webresource.tags.css` returns common CSS dependencies as html `<style>` tags
  - `webresource.tags.js` returns common dependencies as html `<script>` and `<style>` tags
  */
    expand?: Array<string>;
    /**
  * The space key used for resolving embedded content (page includes,
  files, and links) in the content body. For example, if the source content
  contains the link `<ac:link><ri:page ri:content-title="Example page" /><ac:link>`
  and the `spaceKeyContext=TEST` parameter is provided, then the link
  will be converted to a link to the "Example page" page in the "TEST" space.
  */
    spaceKeyContext?: string;
    /**
  * The content ID used to find the space for resolving embedded content
  (page includes, files, and links) in the content body. For example,
  if the source content contains the link `<ac:link><ri:page ri:content-title="Example page" /><ac:link>`
  and the `contentIdContext=123` parameter is provided, then the link
  will be converted to a link to the "Example page" page in the same space
  that has the content with ID=123. Note, `spaceKeyContext` will be ignored
  if this parameter is provided.
  */
    contentIdContext?: string;
    /**
  * If this field is false, the cache will erase its current value and begin a new conversion.
  If this field is true, the cache will not erase its current value, and will set the status of the
  async conversion to RERUNNING. Once the data is updated, the status will change to COMPLETED.
  Large macros that take long to convert, and whose data need not immediately up to date (same as previous conversion's result within last 5 minutes)
  should set this fields to true. Cache values are stored per user per content body and expansions.
  */
    allowCache?: boolean;
    /**
  * Mode used for rendering embedded content, like attachments.
  
  - `current` renders the embedded content using the latest version.
  - `version-at-save` renders the embedded content using the version at
  the time of save.
  */
    embeddedContentRender?: "current" | "version-at-save";
    body: ContentBodyCreate;
}
declare type AsyncConvertContentBodyResponseOKType = AsyncIdAsResponse;
export interface AsyncConvertContentBodyResponseOK extends AsyncConvertContentBodyResponseOKType {
}
export declare type AsyncConvertContentBodyResponseError = undefined;
export interface GetAsyncConvertContentBodyResultRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The asyncId of the macro task to get the converted body.
     */
    id: string;
}
declare type GetAsyncConvertContentBodyResultResponseOKType = AsyncContentBodyAsResponse;
export interface GetAsyncConvertContentBodyResultResponseOK extends GetAsyncConvertContentBodyResultResponseOKType {
}
export declare type GetAsyncConvertContentBodyResultResponseError = undefined;
export {};
//# sourceMappingURL=body.d.ts.map