/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { LabelArrayAsResponse } from "../../definitions/LabelArrayAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { LabelCreateArray } from "../../definitions/LabelCreateArray";
import { LabelCreate } from "../../definitions/LabelCreate";
export interface GetContentLabelsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its labels.
     */
    id: string;
    /**
  * Filters the results to labels with the specified prefix. If this parameter
  is not specified, then labels with any prefix will be returned.
  
  - `global` prefix is used by default when a user adds a label
  via the UI.
  - `my` prefix can be explicitly added by a user when adding a label
  via the UI, e.g. 'my:example-label'. Also, when a page is selected as
  a favourite, the 'my:favourite' label is automatically added.
  - `team` can used when adding labels via [Add labels to content](#api-content-id-label-post)
  but is not used in the UI.
  */
    prefix?: "global" | "my" | "team";
    /**
     * The starting index of the returned labels.
     */
    start?: number;
    /**
  * The maximum number of labels to return per page. Note,
  this may be restricted by fixed system limits.
  */
    limit?: number;
}
declare type GetContentLabelsResponseOKType = LabelArrayAsResponse;
export interface GetContentLabelsResponseOK extends GetContentLabelsResponseOKType {
}
export declare type GetContentLabelsResponseError = undefined;
export interface AddContentLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that will have labels added to it.
     */
    id: string;
    body: LabelCreateArray | LabelCreate;
}
declare type AddContentLabelResponseOKType = LabelArrayAsResponse;
export interface AddContentLabelResponseOK extends AddContentLabelResponseOKType {
}
export declare type AddContentLabelResponseError = undefined;
export interface RemoveContentLabelWithQueryParameterRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that the label will be removed from.
     */
    id: string;
    /**
     * The name of the label to be removed.
     */
    name: string;
}
export declare type RemoveContentLabelWithQueryParameterResponseOK = undefined;
export declare type RemoveContentLabelWithQueryParameterResponseError = undefined;
export interface RemoveContentLabelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that the label will be removed from.
     */
    id: string;
    /**
     * The name of the label to be removed.
     */
    label: string;
}
export declare type RemoveContentLabelResponseOK = undefined;
export declare type RemoveContentLabelResponseError = undefined;
export {};
//# sourceMappingURL=label.d.ts.map