/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentPropertyArrayAsResponse } from "../../definitions/ContentPropertyArrayAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentPropertyCreate } from "../../definitions/ContentPropertyCreate";
import { ContentPropertyAsResponse } from "../../definitions/ContentPropertyAsResponse";
import { ContentPropertyUpdate } from "../../definitions/ContentPropertyUpdate";
import { ContentPropertyCreateNoKey } from "../../definitions/ContentPropertyCreateNoKey";
export interface GetContentPropertiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its properties.
     */
    id: string;
    /**
     * The key of the content property.
     */
    key?: Array<string>;
    /**
  * A multi-value parameter indicating which properties of the content to
  expand. By default, the `version` object is expanded.
  
  - `content` returns the content that the property is stored against.
  - `version` returns information about the version of the property, such
  as the version number, when it was created, etc.
  */
    expand?: Array<"content" | "version">;
    /**
     * The starting index of the returned properties.
     */
    start?: number;
    /**
  * The maximum number of properties to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
}
declare type GetContentPropertiesResponseOKType = ContentPropertyArrayAsResponse;
export interface GetContentPropertiesResponseOK extends GetContentPropertiesResponseOKType {
}
export declare type GetContentPropertiesResponseError = undefined;
export interface CreateContentPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to add the property to.
     */
    id: string;
    body: ContentPropertyCreate;
}
declare type CreateContentPropertyResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyResponseOK extends CreateContentPropertyResponseOKType {
}
export declare type CreateContentPropertyResponseError = undefined;
export interface GetContentPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for the property.
     */
    id: string;
    /**
     * The key of the content property.
     */
    key: string;
    /**
  * A multi-value parameter indicating which properties of the content to
  expand. By default, the `version` object is expanded.
  
  - `content` returns the content that the property is stored against.
  - `version` returns information about the version of the property, such
  as the version number, when it was created, etc.
  */
    expand?: Array<"content" | "version">;
    /**
  * Filter the results to a set of content based on their status. If set to `any`,
  content with any status is returned. By default it will fetch current and archived statuses `?status=current&status=archived`.
  All supported statuses
  
  - any
  - archived
  - current
  - deleted
  - draft
  - trashed
  */
    status?: Array<string>;
}
declare type GetContentPropertyResponseOKType = ContentPropertyAsResponse;
export interface GetContentPropertyResponseOK extends GetContentPropertyResponseOKType {
}
export declare type GetContentPropertyResponseError = undefined;
export interface UpdateContentPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that the property belongs to.
     */
    id: string;
    /**
     * The key of the property.
     */
    key: string;
    body: ContentPropertyUpdate;
}
declare type UpdateContentPropertyResponseOKType = ContentPropertyAsResponse;
export interface UpdateContentPropertyResponseOK extends UpdateContentPropertyResponseOKType {
}
export declare type UpdateContentPropertyResponseError = undefined;
export interface CreateContentPropertyForKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to add the property to.
     */
    id: string;
    /**
     * The key of the content property. Required.
     */
    key: string;
    body: ContentPropertyCreateNoKey;
}
declare type CreateContentPropertyForKeyResponseOKType = ContentPropertyAsResponse;
export interface CreateContentPropertyForKeyResponseOK extends CreateContentPropertyForKeyResponseOKType {
}
export declare type CreateContentPropertyForKeyResponseError = undefined;
export interface DeleteContentPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that the property belongs to.
     */
    id: string;
    /**
     * The key of the property.
     */
    key: string;
}
export declare type DeleteContentPropertyResponseOK = undefined;
export declare type DeleteContentPropertyResponseError = undefined;
export {};
//# sourceMappingURL=property.d.ts.map