/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentRestrictionArrayAsResponse } from "../../definitions/ContentRestrictionArrayAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentRestrictionAddOrUpdateArray } from "../../definitions/ContentRestrictionAddOrUpdateArray";
import { CommonError } from "../../errorStrategy";
import { GenericLinksAsResponse } from "../../definitions/GenericLinksAsResponse";
import { ContentRestrictionAsResponse } from "../../definitions/ContentRestrictionAsResponse";
export interface GetContentRestrictionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its restrictions.
     */
    id: string;
    /**
  * A multi-value parameter indicating which properties of the content
  restrictions to expand. By default, the following objects are expanded:
  `restrictions.user`, `restrictions.group`.
  
  - `restrictions.user` returns the piece of content that the restrictions are
  applied to.
  - `restrictions.group` returns the piece of content that the restrictions are
  applied to.
  - `content` returns the piece of content that the restrictions are
  applied to.
  */
    expand?: Array<"restrictions.user" | "read.restrictions.user" | "update.restrictions.user" | "restrictions.group" | "read.restrictions.group" | "update.restrictions.group" | "content">;
    /**
     * The starting index of the users and groups in the returned restrictions.
     */
    start?: number;
    /**
  * The maximum number of users and the maximum number of groups, in the
  returned restrictions, to return per page. Note, this may be restricted
  by fixed system limits.
  */
    limit?: number;
}
declare type GetContentRestrictionsResponseOKType = ContentRestrictionArrayAsResponse;
export interface GetContentRestrictionsResponseOK extends GetContentRestrictionsResponseOKType {
}
export declare type GetContentRestrictionsResponseError = undefined;
export interface UpdateContentRestrictionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to update restrictions for.
     */
    id: string;
    /**
  * A multi-value parameter indicating which properties of the content
  restrictions (returned in response) to expand.
  
  - `restrictions.user` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `restrictions.group` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `content` returns the piece of content that the restrictions are
  applied to.
  */
    expand?: Array<"restrictions.user" | "read.restrictions.user" | "update.restrictions.user" | "restrictions.group" | "read.restrictions.group" | "update.restrictions.group" | "content">;
    body: ContentRestrictionAddOrUpdateArray;
}
declare type UpdateContentRestrictionsResponseOKType = ContentRestrictionArrayAsResponse;
export interface UpdateContentRestrictionsResponseOK extends UpdateContentRestrictionsResponseOKType {
}
export declare type UpdateContentRestrictionsResponseError = undefined;
export interface AddContentRestrictionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to add restrictions to.
     */
    id: string;
    /**
  * A multi-value parameter indicating which properties of the content
  restrictions (returned in response) to expand.
  
  - `restrictions.user` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `restrictions.group` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `content` returns the piece of content that the restrictions are
  applied to.
  */
    expand?: Array<"restrictions.user" | "read.restrictions.user" | "update.restrictions.user" | "restrictions.group" | "read.restrictions.group" | "update.restrictions.group" | "content">;
    body: ContentRestrictionAddOrUpdateArray;
}
declare type AddContentRestrictionsResponseOKType = ContentRestrictionArrayAsResponse;
export interface AddContentRestrictionsResponseOK extends AddContentRestrictionsResponseOKType {
}
export declare type AddContentRestrictionsResponseError = undefined;
export interface DeleteContentRestrictionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to remove restrictions from.
     */
    id: string;
    /**
  * A multi-value parameter indicating which properties of the content
  restrictions (returned in response) to expand.
  
  - `restrictions.user` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `restrictions.group` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `content` returns the piece of content that the restrictions are
  applied to.
  */
    expand?: Array<"restrictions.user" | "read.restrictions.user" | "update.restrictions.user" | "restrictions.group" | "read.restrictions.group" | "update.restrictions.group" | "content">;
}
declare type DeleteContentRestrictionsResponseOKType = ContentRestrictionArrayAsResponse;
export interface DeleteContentRestrictionsResponseOK extends DeleteContentRestrictionsResponseOKType {
}
export declare type DeleteContentRestrictionsResponseError = undefined;
export interface GetContentRestrictionsByOperationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its restrictions.
     */
    id: string;
    /**
       * A multi-value parameter indicating which properties of the content
       restrictions to expand.
      
       - `restrictions.user` returns the piece of content that the restrictions are
       applied to. Expanded by default.
       - `restrictions.group` returns the piece of content that the restrictions are
       applied to. Expanded by default.
       - `content` returns the piece of content that the restrictions are
       applied to.
       */
    expand?: Array<"restrictions.user" | "restrictions.group" | "content">;
}
declare type GetContentRestrictionsByOperationResponseOKType = {
    _links: GenericLinksAsResponse;
} & {
    [x: string]: ContentRestrictionAsResponse;
};
export interface GetContentRestrictionsByOperationResponseOK extends Record<string, GetContentRestrictionsByOperationResponseOKType> {
}
export interface GetContentRestrictionsByOperationResponseError extends CommonError {
}
export interface GetContentRestrictionsForOperationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its restrictions.
     */
    id: string;
    /**
     * The operation type of the restrictions to be returned.
     */
    operationKey: "read" | "update";
    /**
  * A multi-value parameter indicating which properties of the content
  restrictions to expand.
  
  - `restrictions.user` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `restrictions.group` returns the piece of content that the restrictions are
  applied to. Expanded by default.
  - `content` returns the piece of content that the restrictions are
  applied to.
  */
    expand?: Array<"restrictions.user" | "restrictions.group" | "content">;
    /**
     * The starting index of the users and groups in the returned restrictions.
     */
    start?: number;
    /**
  * The maximum number of users and the maximum number of groups, in the
  returned restrictions, to return per page. Note, this may be restricted
  by fixed system limits.
  */
    limit?: number;
}
declare type GetContentRestrictionsForOperationResponseOKType = ContentRestrictionAsResponse;
export interface GetContentRestrictionsForOperationResponseOK extends GetContentRestrictionsForOperationResponseOKType {
}
export declare type GetContentRestrictionsForOperationResponseError = undefined;
export {};
//# sourceMappingURL=restriction.d.ts.map