/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { VersionArrayAsResponse } from "../../definitions/VersionArrayAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { VersionRestore } from "../../definitions/VersionRestore";
import { VersionAsResponse } from "../../definitions/VersionAsResponse";
export interface GetContentVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its versions.
     */
    id: string;
    /**
     * The starting index of the returned versions.
     */
    start?: number;
    /**
  * The maximum number of versions to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
  * A multi-value parameter indicating which properties of the content to expand. By default, the `content`
  object is expanded.
  
  - `collaborators` returns the users that collaborated on the version.
  - `content` returns the content for the version.
  */
    expand?: Array<string>;
}
declare type GetContentVersionsResponseOKType = VersionArrayAsResponse;
export interface GetContentVersionsResponseOK extends GetContentVersionsResponseOKType {
}
export declare type GetContentVersionsResponseError = undefined;
export interface RestoreContentVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content for which the history will be restored.
     */
    id: string;
    /**
  * A multi-value parameter indicating which properties of the content to expand. By default, the `content`
  object is expanded.
  
  - `collaborators` returns the users that collaborated on the version.
  - `content` returns the content for the version.
  */
    expand?: Array<string>;
    body: VersionRestore;
}
declare type RestoreContentVersionResponseOKType = VersionAsResponse;
export interface RestoreContentVersionResponseOK extends RestoreContentVersionResponseOKType {
}
export declare type RestoreContentVersionResponseError = undefined;
export interface GetContentVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content to be queried for its version.
     */
    id: string;
    /**
     * The number of the version to be retrieved.
     */
    versionNumber: number;
    /**
  * A multi-value parameter indicating which properties of the content to expand. By default, the `content`
  object is expanded.
  
  - `collaborators` returns the users that collaborated on the version.
  - `content` returns the content for the version.
  */
    expand?: Array<string>;
}
declare type GetContentVersionResponseOKType = VersionAsResponse;
export interface GetContentVersionResponseOK extends GetContentVersionResponseOKType {
}
export declare type GetContentVersionResponseError = undefined;
export interface DeleteContentVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content that the version will be deleted from.
     */
    id: string;
    /**
  * The number of the version to be deleted. The version number starts
  from 1 up to current version.
  */
    versionNumber: number;
}
export declare type DeleteContentVersionResponseOK = undefined;
export declare type DeleteContentVersionResponseError = undefined;
export {};
//# sourceMappingURL=version.d.ts.map