/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { RelationArrayAsResponse } from "../definitions/RelationArrayAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { RelationAsResponse } from "../definitions/RelationAsResponse";
export interface FindTargetEntitiesRelatedToSourceEntityRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The name of the relationship. This method supports relationships created via
  [Create relationship](#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put).
  Note, this method does not support 'like' or 'favourite' relationships.
  */
    relationName: string;
    /**
     * The source entity type of the relationship.
     */
    sourceType: "user" | "content" | "space";
    /**
  * The identifier for the source entity:
  
  - If `sourceType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `sourceType` is 'content', then specify the content ID.
  - If `sourceType` is 'space', then specify the space key.
  */
    sourceKey: string;
    /**
     * The target entity type of the relationship.
     */
    targetType: "user" | "content" | "space";
    /**
  * The status of the source. This parameter is only used when the
  `sourceType` is 'content'.
  */
    sourceStatus?: string;
    /**
  * The status of the target. This parameter is only used when the
  `targetType` is 'content'.
  */
    targetStatus?: string;
    /**
  * The version of the source. This parameter is only used when the
  `sourceType` is 'content' and the `sourceStatus` is 'historical'.
  */
    sourceVersion?: number;
    /**
  * The version of the target. This parameter is only used when the
  `targetType` is 'content' and the `targetStatus` is 'historical'.
  */
    targetVersion?: number;
    /**
  * A multi-value parameter indicating which properties of the response
  object to expand.
  
  - `relationData` returns information about the relationship, such as
  who created it and when it was created.
  - `source` returns the source entity.
  - `target` returns the target entity.
  */
    expand?: Array<"relationData" | "source" | "target">;
    /**
     * The starting index of the returned relationships.
     */
    start?: number;
    /**
  * The maximum number of relationships to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
}
declare type FindTargetEntitiesRelatedToSourceEntityResponseOKType = RelationArrayAsResponse;
export interface FindTargetEntitiesRelatedToSourceEntityResponseOK extends FindTargetEntitiesRelatedToSourceEntityResponseOKType {
}
export declare type FindTargetEntitiesRelatedToSourceEntityResponseError = undefined;
export interface FindRelationshipFromSourceToTargetRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The name of the relationship. This method supports the 'favourite'
  (i.e. 'save for later') relationship as well as any other relationship
  types created via [Create relationship](#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put).
  */
    relationName: string;
    /**
  * The source entity type of the relationship. This must be 'user', if
  the `relationName` is 'favourite'.
  */
    sourceType: "user" | "content" | "space";
    /**
  * - The identifier for the source entity:
  
  - If `sourceType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `sourceType` is 'content', then specify the content ID.
  - If `sourceType` is 'space', then specify the space key.
  */
    sourceKey: string;
    /**
  * The target entity type of the relationship. This must be 'space' or
  'content', if the `relationName` is 'favourite'.
  */
    targetType: "user" | "content" | "space";
    /**
  * The identifier for the target entity:
  
  - If `targetType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `targetType` is 'content', then specify the content ID.
  - If `targetType` is 'space', then specify the space key.
  */
    targetKey: string;
    /**
  * The status of the source. This parameter is only used when the
  `sourceType` is 'content'.
  */
    sourceStatus?: string;
    /**
  * The status of the target. This parameter is only used when the
  `targetType` is 'content'.
  */
    targetStatus?: string;
    /**
  * The version of the source. This parameter is only used when the
  `sourceType` is 'content' and the `sourceStatus` is 'historical'.
  */
    sourceVersion?: number;
    /**
  * The version of the target. This parameter is only used when the
  `targetType` is 'content' and the `targetStatus` is 'historical'.
  */
    targetVersion?: number;
    /**
  * A multi-value parameter indicating which properties of the response
  object to expand.
  
  - `relationData` returns information about the relationship, such as
  who created it and when it was created.
  - `source` returns the source entity.
  - `target` returns the target entity.
  */
    expand?: Array<"relationData" | "source" | "target">;
}
declare type FindRelationshipFromSourceToTargetResponseOKType = RelationAsResponse;
export interface FindRelationshipFromSourceToTargetResponseOK extends FindRelationshipFromSourceToTargetResponseOKType {
}
export declare type FindRelationshipFromSourceToTargetResponseError = undefined;
export interface CreateRelationshipRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The name of the relationship. This method supports the 'favourite'
  (i.e. 'save for later') relationship. You can also specify any other
  value for this parameter to create a custom relationship type.
  */
    relationName: string;
    /**
  * The source entity type of the relationship. This must be 'user', if
  the `relationName` is 'favourite'.
  */
    sourceType: "user" | "content" | "space";
    /**
  * - The identifier for the source entity:
  
  - If `sourceType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `sourceType` is 'content', then specify the content ID.
  - If `sourceType` is 'space', then specify the space key.
  */
    sourceKey: string;
    /**
  * The target entity type of the relationship. This must be 'space' or
  'content', if the `relationName` is 'favourite'.
  */
    targetType: "user" | "content" | "space";
    /**
  * - The identifier for the target entity:
  
  - If `targetType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `targetType` is 'content', then specify the content ID.
  - If `targetType` is 'space', then specify the space key.
  */
    targetKey: string;
    /**
  * The status of the source. This parameter is only used when the
  `sourceType` is 'content'.
  */
    sourceStatus?: string;
    /**
  * The status of the target. This parameter is only used when the
  `targetType` is 'content'.
  */
    targetStatus?: string;
    /**
  * The version of the source. This parameter is only used when the
  `sourceType` is 'content' and the `sourceStatus` is 'historical'.
  */
    sourceVersion?: number;
    /**
  * The version of the target. This parameter is only used when the
  `targetType` is 'content' and the `targetStatus` is 'historical'.
  */
    targetVersion?: number;
}
declare type CreateRelationshipResponseOKType = RelationAsResponse;
export interface CreateRelationshipResponseOK extends CreateRelationshipResponseOKType {
}
export declare type CreateRelationshipResponseError = undefined;
export interface DeleteRelationshipRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the relationship.
     */
    relationName: string;
    /**
  * The source entity type of the relationship. This must be 'user', if
  the `relationName` is 'favourite'.
  */
    sourceType: "user" | "content" | "space";
    /**
  * - The identifier for the source entity:
  
  - If `sourceType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `sourceType` is 'content', then specify the content ID.
  - If `sourceType` is 'space', then specify the space key.
  */
    sourceKey: string;
    /**
  * The target entity type of the relationship. This must be 'space' or
  'content', if the `relationName` is 'favourite'.
  */
    targetType: "user" | "content" | "space";
    /**
  * - The identifier for the target entity:
  
  - If `targetType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `targetType` is 'content', then specify the content ID.
  - If `targetType` is 'space', then specify the space key.
  */
    targetKey: string;
    /**
  * The status of the source. This parameter is only used when the
  `sourceType` is 'content'.
  */
    sourceStatus?: string;
    /**
  * The status of the target. This parameter is only used when the
  `targetType` is 'content'.
  */
    targetStatus?: string;
    /**
  * The version of the source. This parameter is only used when the
  `sourceType` is 'content' and the `sourceStatus` is 'historical'.
  */
    sourceVersion?: number;
    /**
  * The version of the target. This parameter is only used when the
  `targetType` is 'content' and the `targetStatus` is 'historical'.
  */
    targetVersion?: number;
}
export declare type DeleteRelationshipResponseOK = undefined;
export declare type DeleteRelationshipResponseError = undefined;
export interface FindSourceEntitiesRelatedToTargetEntityRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The name of the relationship. This method supports relationships created via
  [Create relationship](#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put).
  Note, this method does not support 'like' or 'favourite' relationships.
  */
    relationName: string;
    /**
     * The source entity type of the relationship.
     */
    sourceType: "user" | "content" | "space";
    /**
     * The target entity type of the relationship.
     */
    targetType: "user" | "content" | "space";
    /**
  * The identifier for the target entity:
  
  - If `targetType` is `user`, then specify either `current` (logged-in user), the user key of the user, or
  the account ID of the user. Note that the user key has been deprecated in favor of the account ID for this parameter. See the
  [migration guide](https://developer.atlassian.com/cloud/confluence/deprecation-notice-user-privacy-api-migration-guide/)
  for details.
  - If `targetType` is 'content', then specify the content ID.
  - If `targetType` is 'space', then specify the space key.
  */
    targetKey: string;
    /**
  * The status of the source. This parameter is only used when the
  `sourceType` is 'content'.
  */
    sourceStatus?: string;
    /**
  * The status of the target. This parameter is only used when the
  `targetType` is 'content'.
  */
    targetStatus?: string;
    /**
  * The version of the source. This parameter is only used when the
  `sourceType` is 'content' and the `sourceStatus` is 'historical'.
  */
    sourceVersion?: number;
    /**
  * The version of the target. This parameter is only used when the
  `targetType` is 'content' and the `targetStatus` is 'historical'.
  */
    targetVersion?: number;
    /**
  * A multi-value parameter indicating which properties of the response
  object to expand.
  
  - `relationData` returns information about the relationship, such as
  who created it and when it was created.
  - `source` returns the source entity.
  - `target` returns the target entity.
  */
    expand?: Array<"relationData" | "source" | "target">;
    /**
     * The starting index of the returned relationships.
     */
    start?: number;
    /**
  * The maximum number of relationships to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
}
declare type FindSourceEntitiesRelatedToTargetEntityResponseOKType = RelationArrayAsResponse;
export interface FindSourceEntitiesRelatedToTargetEntityResponseOK extends FindSourceEntitiesRelatedToTargetEntityResponseOKType {
}
export declare type FindSourceEntitiesRelatedToTargetEntityResponseError = undefined;
export {};
//# sourceMappingURL=relation.d.ts.map