/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SearchPageResponseSearchResultAsResponse } from "../definitions/SearchPageResponseSearchResultAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface SearchContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The CQL query to be used for the search. See
  [Advanced Searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/)
  for instructions on how to build a CQL query.
  */
    cql: string;
    /**
  * The space, content, and content status to execute the search
  against.
  
  - `spaceKey` Key of the space to search against. Optional.
  - `contentId` ID of the content to search against. Optional. Must be
  in the space specified by `spaceKey`.
  - `contentStatuses` Content statuses to search against. Optional.
  
  Specify these values in an object. For example,
  `cqlcontext={%22spaceKey%22:%22TEST%22, %22contentId%22:%22123%22}`
  */
    cqlcontext?: string;
    /**
     * Pointer to a set of search results, returned as part of the `next` or `prev` URL from the previous search call.
     */
    cursor?: string;
    next?: boolean;
    prev?: boolean;
    /**
  * The maximum number of content objects to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
     * The start point of the collection to return
     */
    start?: number;
    /**
     * Whether to include content from archived spaces in the results.
     */
    includeArchivedSpaces?: boolean;
    /**
     * Whether to exclude current spaces and only show archived spaces.
     */
    excludeCurrentSpaces?: boolean;
    /**
     * The excerpt strategy to apply to the result
     */
    excerpt?: "highlight" | "indexed" | "none" | "highlight_unescaped" | "indexed_unescaped";
    /**
  * Filters users by permission type. Use `none` to default to licensed users, `externalCollaborator`
  for external/guest users, and `all` to include all permission types.
  */
    sitePermissionTypeFilter?: "all" | "externalCollaborator" | "none";
    _?: number;
    expand?: Array<string>;
}
declare type SearchContentResponseOKType = SearchPageResponseSearchResultAsResponse;
export interface SearchContentResponseOK extends SearchContentResponseOKType {
}
export declare type SearchContentResponseError = undefined;
export interface SearchUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The CQL query to be used for the search. See
  [Advanced Searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/)
  for instructions on how to build a CQL query.
  
  Example queries:
            cql=type=user will return up to 10k users
            cql=user="1234" will return user with accountId "1234"
            You can also use IN, NOT IN, != operators
            cql=user IN ("12", "34") will return users with accountids "12" and "34"
            cql=user.fullname~jo will return users with nickname/full name starting with "jo"
            cql=user.accountid="123" will return user with accountId "123"
  */
    cql: string;
    /**
     * The starting index of the returned users.
     */
    start?: number;
    /**
  * The maximum number of user objects to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
  * A multi-value parameter indicating which properties of the user to expand.
  
  - `operations` returns the operations for the user, which are used
  when setting permissions.
  - `personalSpace` returns the personal space of the user.
  */
    expand?: Array<string>;
    /**
  * Filters users by permission type. Use `none` to default to licensed users, `externalCollaborator`
  for external/guest users, and `all` to include all permission types.
  */
    sitePermissionTypeFilter?: "all" | "externalCollaborator" | "none";
}
declare type SearchUsersResponseOKType = SearchPageResponseSearchResultAsResponse;
export interface SearchUsersResponseOK extends SearchUsersResponseOKType {
}
export declare type SearchUsersResponseError = undefined;
export {};
//# sourceMappingURL=search.d.ts.map