/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SpaceArrayAsResponse } from "../definitions/SpaceArrayAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SpaceCreate } from "../definitions/SpaceCreate";
import { SpaceAsResponse } from "../definitions/SpaceAsResponse";
import { SpaceUpdate } from "../definitions/SpaceUpdate";
import { LongTaskAsResponse } from "../definitions/LongTaskAsResponse";
export interface GetSpacesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The key of the space to be returned. To return multiple spaces,
  specify this parameter multiple times with different values.
  */
    spaceKey?: Array<string>;
    /**
  * The id of the space to be returned. To return multiple spaces,
  specify this parameter multiple times with different values.
  */
    spaceId?: Array<number>;
    /**
     * Filter the results to spaces based on their type.
     */
    type?: "global" | "collaboration" | "knowledge_base" | "personal";
    /**
     * Filter the results to spaces based on their status.
     */
    status?: "current" | "archived";
    /**
     * Filter the results to spaces based on their label.
     */
    label?: Array<string>;
    /**
  * Filter the results to the favourite spaces of the user specified by
  `favouriteUserKey`. Note, 'favourite' spaces are also
  known as 'saved for later' spaces.
  */
    favourite?: boolean;
    /**
  * The userKey of the user, whose favourite spaces are used to filter
  the results when using the `favourite` parameter.
  
  Leave blank for the current user. Use [Get user](#api-user-get) to
  get the userKey for a user.
  */
    favouriteUserKey?: string;
    /**
  * A multi-value parameter indicating which properties of the spaces to
  expand, where:
  
    - `settings` returns the settings for the space, similar to [Get space settings](#api-space-spaceKey-settings-get).
    - `metadata` returns the space metadata.
    - `metadata.labels` returns the space labels, which are used to categorize the space.
    - `operations` returns the operations for a space, which are used when setting permissions.
    - `lookAndFeel` returns information about the look and feel of the space, including the color scheme.
    - `permissions` returns the permissions for the space. Note that this may return permissions for deleted groups,
    because deleting a group doesn't remove associated space permissions.
    - `icon` returns information about space icon.
    - `description` returns the description of the space.
    - `description.plain` returns the description of the space, the plain format.
    - `description.view` returns the description of the space, the view format.
    - `theme` returns information about the space theme.
    - `homepage` returns information about the space homepage.
    - `history` returns information about the history of the space.
  */
    expand?: Array<"settings" | "metadata" | "metadata.labels" | "operations" | "lookAndFeel" | "permissions" | "icon" | "description" | "description.plain" | "description.view" | "theme" | "homepage" | "history">;
    /**
     * The starting index of the returned spaces.
     */
    start?: number;
    /**
  * The maximum number of spaces to return per page. Note, this may be
  restricted by fixed system limits.
  */
    limit?: number;
}
declare type GetSpacesResponseOKType = SpaceArrayAsResponse;
export interface GetSpacesResponseOK extends GetSpacesResponseOKType {
}
export declare type GetSpacesResponseError = undefined;
export interface CreateSpaceRequest extends HeadersOption, ErrorStrategyOption {
    body: SpaceCreate;
}
declare type CreateSpaceResponseOKType = SpaceAsResponse;
export interface CreateSpaceResponseOK extends CreateSpaceResponseOKType {
}
export declare type CreateSpaceResponseError = undefined;
export interface GetSpaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space to be returned.
     */
    spaceKey: string;
    /**
  * A multi-value parameter indicating which properties of the spaces to
  expand, where:
  
    - `settings` returns the settings for the space, similar to [Get space settings](#api-space-spaceKey-settings-get).
    - `metadata` returns the space metadata.
    - `metadata.labels` returns the space labels, which are used to categorize the space.
    - `operations` returns the operations for a space, which are used when setting permissions.
    - `lookAndFeel` returns information about the look and feel of the space, including the color scheme.
    - `permissions` returns the permissions for the space. Note that this may return permissions for deleted groups,
    because deleting a group doesn't remove associated space permissions.
    - `icon` returns information about space icon.
    - `description` returns the description of the space.
    - `description.plain` returns the description of the space, the plain format.
    - `description.view` returns the description of the space, the view format.
    - `theme` returns information about the space theme.
    - `homepage` returns information about the space homepage.
    - `history` returns information about the history of the space.
  */
    expand?: Array<"settings" | "metadata" | "metadata.labels" | "operations" | "lookAndFeel" | "permissions" | "icon" | "description" | "description.plain" | "description.view" | "theme" | "homepage" | "history">;
}
declare type GetSpaceResponseOKType = SpaceAsResponse;
export interface GetSpaceResponseOK extends GetSpaceResponseOKType {
}
export declare type GetSpaceResponseError = undefined;
export interface UpdateSpaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space to update.
     */
    spaceKey: string;
    body: SpaceUpdate;
}
declare type UpdateSpaceResponseOKType = SpaceAsResponse;
export interface UpdateSpaceResponseOK extends UpdateSpaceResponseOKType {
}
export declare type UpdateSpaceResponseError = undefined;
export interface DeleteSpaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space to delete.
     */
    spaceKey: string;
}
declare type DeleteSpaceResponseOKType = LongTaskAsResponse;
export interface DeleteSpaceResponseOK extends DeleteSpaceResponseOKType {
}
export declare type DeleteSpaceResponseError = undefined;
export {};
//# sourceMappingURL=space.d.ts.map