/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { SpacePropertyArrayAsResponse } from "../../definitions/SpacePropertyArrayAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SpacePropertyCreate } from "../../definitions/SpacePropertyCreate";
import { SpacePropertyAsResponse } from "../../definitions/SpacePropertyAsResponse";
import { SpacePropertyUpdate } from "../../definitions/SpacePropertyUpdate";
import { SpacePropertyCreateNoKey } from "../../definitions/SpacePropertyCreateNoKey";
export interface GetSpacePropertiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space to be queried for its properties.
     */
    spaceKey: string;
    /**
  * A multi-value parameter indicating which properties of the space
  property to expand. By default, the `version` object is expanded.
  
  - `version` returns information about the version of the content.
  - `space` returns the space that the properties are in.
  */
    expand?: Array<"version" | "space">;
    /**
     * The starting index of the returned objects.
     */
    start?: number;
    /**
  * The maximum number of properties to return per page. Note, this may be
  restricted by fixed system limits.
  */
    limit?: number;
}
declare type GetSpacePropertiesResponseOKType = SpacePropertyArrayAsResponse;
export interface GetSpacePropertiesResponseOK extends GetSpacePropertiesResponseOKType {
}
export declare type GetSpacePropertiesResponseError = undefined;
export interface CreateSpacePropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space that the property will be created in.
     */
    spaceKey: string;
    body: SpacePropertyCreate;
}
declare type CreateSpacePropertyResponseOKType = SpacePropertyAsResponse;
export interface CreateSpacePropertyResponseOK extends CreateSpacePropertyResponseOKType {
}
export declare type CreateSpacePropertyResponseError = undefined;
export interface GetSpacePropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space that the property is in.
     */
    spaceKey: string;
    /**
     * The key of the space property.
     */
    key: string;
    /**
  * A multi-value parameter indicating which properties of the space
  property to expand. By default, the `version` object is expanded.
  
  - `version` returns information about the version of the content.
  - `space` returns the space that the properties are in.
  */
    expand?: Array<"version" | "space">;
}
declare type GetSpacePropertyResponseOKType = SpacePropertyAsResponse;
export interface GetSpacePropertyResponseOK extends GetSpacePropertyResponseOKType {
}
export declare type GetSpacePropertyResponseError = undefined;
export interface UpdateSpacePropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space that the property is in.
     */
    spaceKey: string;
    /**
     * The key of the property to be updated.
     */
    key: string;
    body: SpacePropertyUpdate;
}
declare type UpdateSpacePropertyResponseOKType = SpacePropertyAsResponse;
export interface UpdateSpacePropertyResponseOK extends UpdateSpacePropertyResponseOKType {
}
export declare type UpdateSpacePropertyResponseError = undefined;
export interface CreateSpacePropertyForKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space that the property will be created in.
     */
    spaceKey: string;
    /**
     * The key of the property to be created.
     */
    key: string;
    body: SpacePropertyCreateNoKey;
}
declare type CreateSpacePropertyForKeyResponseOKType = SpacePropertyAsResponse;
export interface CreateSpacePropertyForKeyResponseOK extends CreateSpacePropertyForKeyResponseOKType {
}
export declare type CreateSpacePropertyForKeyResponseError = undefined;
export interface DeleteSpacePropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The key of the space that the property is in.
     */
    spaceKey: string;
    /**
     * The key of the property to be deleted.
     */
    key: string;
}
export declare type DeleteSpacePropertyResponseOK = undefined;
export declare type DeleteSpacePropertyResponseError = undefined;
export {};
//# sourceMappingURL=property.d.ts.map