/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ContentTemplateUpdate } from "../definitions/ContentTemplateUpdate";
import { ContentTemplateAsResponse } from "../definitions/ContentTemplateAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ContentTemplateCreate } from "../definitions/ContentTemplateCreate";
import { BlueprintTemplateArrayAsResponse } from "../definitions/BlueprintTemplateArrayAsResponse";
import { ContentTemplateArrayAsResponse } from "../definitions/ContentTemplateArrayAsResponse";
export interface UpdateContentTemplateRequest extends HeadersOption, ErrorStrategyOption {
    body: ContentTemplateUpdate;
}
declare type UpdateContentTemplateResponseOKType = ContentTemplateAsResponse;
export interface UpdateContentTemplateResponseOK extends UpdateContentTemplateResponseOKType {
}
export declare type UpdateContentTemplateResponseError = undefined;
export interface CreateContentTemplateRequest extends HeadersOption, ErrorStrategyOption {
    body: ContentTemplateCreate;
}
declare type CreateContentTemplateResponseOKType = ContentTemplateAsResponse;
export interface CreateContentTemplateResponseOK extends CreateContentTemplateResponseOKType {
}
export declare type CreateContentTemplateResponseError = undefined;
export interface GetBlueprintTemplatesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The key of the space to be queried for templates. If the `spaceKey`
  is not specified, global blueprint templates will be returned.
  */
    spaceKey?: string;
    /**
     * The starting index of the returned templates.
     */
    start?: number;
    /**
  * The maximum number of templates to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
  * A multi-value parameter indicating which properties of the template
  to expand.
  
  - `body` or `body.storage` returns the content of the template in storage format.
  */
    expand?: Array<"body" | "body.storage">;
}
declare type GetBlueprintTemplatesResponseOKType = BlueprintTemplateArrayAsResponse;
export interface GetBlueprintTemplatesResponseOK extends GetBlueprintTemplatesResponseOKType {
}
export declare type GetBlueprintTemplatesResponseError = undefined;
export interface GetContentTemplatesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The key of the space to be queried for templates. If the `spaceKey`
  is not specified, global templates will be returned.
  */
    spaceKey?: string;
    /**
     * The starting index of the returned templates.
     */
    start?: number;
    /**
  * The maximum number of templates to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
  * A multi-value parameter indicating which properties of the template
  to expand.
  
  - `body` or `body.storage` returns the content of the template in storage format.
  */
    expand?: Array<"body" | "body.storage">;
}
declare type GetContentTemplatesResponseOKType = ContentTemplateArrayAsResponse;
export interface GetContentTemplatesResponseOK extends GetContentTemplatesResponseOKType {
}
export declare type GetContentTemplatesResponseError = undefined;
export interface GetContentTemplateRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the content template to be returned.
     */
    contentTemplateId: string;
    /**
  * A multi-value parameter indicating which properties of the template
  to expand.
  
  - `body` or `body.storage` returns the content of the template in storage format.
  */
    expand?: Array<"body" | "body.storage">;
}
declare type GetContentTemplateResponseOKType = ContentTemplateAsResponse;
export interface GetContentTemplateResponseOK extends GetContentTemplateResponseOKType {
}
export declare type GetContentTemplateResponseError = undefined;
export interface RemoveTemplateRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the template to be deleted.
     */
    contentTemplateId: string;
}
export declare type RemoveTemplateResponseOK = undefined;
export declare type RemoveTemplateResponseError = undefined;
export {};
//# sourceMappingURL=template.d.ts.map