/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserAsResponse } from "../definitions/UserAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { UserAnonymousAsResponse } from "../definitions/UserAnonymousAsResponse";
import { GroupArrayWithLinksAsResponse } from "../definitions/GroupArrayWithLinksAsResponse";
import { BulkUserLookupArrayAsResponse } from "../definitions/BulkUserLookupArrayAsResponse";
import { AccountIdEmailRecordAsResponse } from "../definitions/AccountIdEmailRecordAsResponse";
import { AccountIdEmailRecordArrayAsResponse } from "../definitions/AccountIdEmailRecordArrayAsResponse";
export interface GetUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The account ID of the user. The accountId uniquely identifies the user across all Atlassian products.
  For example, `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`.
  */
    accountId: string;
    /**
  * A multi-value parameter indicating which properties of the user to
  expand.
  
    - `operations` returns the operations that the user is allowed to do.
    - `personalSpace` returns the user's personal space, if it exists.
    - `isExternalCollaborator`(@deprecated) see `isGuest` in response to find out whether the user is a guest.
  */
    expand?: Array<"operations" | "personalSpace" | "isExternalCollaborator">;
}
declare type GetUserResponseOKType = UserAsResponse;
export interface GetUserResponseOK extends GetUserResponseOKType {
}
export declare type GetUserResponseError = undefined;
export interface GetAnonymousUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * A multi-value parameter indicating which properties of the user to
  expand.
  
    - `operations` returns the operations that the user is allowed to do.
  */
    expand?: Array<"operations">;
}
declare type GetAnonymousUserResponseOKType = UserAnonymousAsResponse;
export interface GetAnonymousUserResponseOK extends GetAnonymousUserResponseOKType {
}
export declare type GetAnonymousUserResponseError = undefined;
export interface GetCurrentUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * A multi-value parameter indicating which properties of the user to
  expand.
  
    - `operations` returns the operations that the user is allowed to do.
    - `personalSpace` returns the user's personal space, if it exists.
    - `isExternalCollaborator`(@deprecated) see `isGuest` in response to find out whether the user is a guest.
  */
    expand?: Array<"operations" | "personalSpace" | "isExternalCollaborator">;
}
declare type GetCurrentUserResponseOKType = UserAsResponse;
export interface GetCurrentUserResponseOK extends GetCurrentUserResponseOKType {
}
export declare type GetCurrentUserResponseError = undefined;
export interface GetGroupsWhereUserMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The account ID of the user. The accountId uniquely identifies the user across all Atlassian products.
  For example, `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`.
  */
    accountId: string;
    /**
     * The starting index of the returned groups.
     */
    start?: number;
    /**
  * The maximum number of groups to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
}
declare type GetGroupsWhereUserMemberResponseOKType = GroupArrayWithLinksAsResponse;
export interface GetGroupsWhereUserMemberResponseOK extends GetGroupsWhereUserMemberResponseOKType {
}
export declare type GetGroupsWhereUserMemberResponseError = undefined;
export interface GetUsersWithIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A list of accountId's of users to be returned.
     */
    accountId: string;
    /**
  * A multi-value parameter indicating which properties of the user to
  expand.
  
    - `operations` returns the operations that the user is allowed to do.
    - `personalSpace` returns the user's personal space, if it exists.
    - `isExternalCollaborator`(@deprecated) use `isGuest` instead to return whether the user is a guest.
  */
    expand?: Array<"operations" | "personalSpace" | "isExternalCollaborator">;
}
declare type GetUsersWithIdsResponseOKType = BulkUserLookupArrayAsResponse;
export interface GetUsersWithIdsResponseOK extends GetUsersWithIdsResponseOKType {
}
export declare type GetUsersWithIdsResponseError = undefined;
export interface GetUserEmailRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The account ID of the user, which uniquely identifies the user across all Atlassian products.
  For example, `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`. Required.
  */
    accountId: string;
}
declare type GetUserEmailResponseOKType = AccountIdEmailRecordAsResponse;
export interface GetUserEmailResponseOK extends GetUserEmailResponseOKType {
}
export declare type GetUserEmailResponseError = undefined;
export interface GetUserEmailsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account IDs of the users.
     */
    accountId: Array<string>;
}
declare type GetUserEmailsResponseOKType = AccountIdEmailRecordArrayAsResponse;
export interface GetUserEmailsResponseOK extends GetUserEmailsResponseOKType {
}
export declare type GetUserEmailsResponseError = undefined;
export {};
//# sourceMappingURL=user.d.ts.map