/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { AccountId } from "../../definitions/AccountId";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { UserArrayAsResponse } from "../../definitions/UserArrayAsResponse";
export interface AddUserGroupMembersByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * GroupId of the group whose membership is updated
     */
    groupId: string;
    body: AccountId;
}
export declare type AddUserGroupMembersByIdResponseOK = undefined;
export declare type AddUserGroupMembersByIdResponseError = undefined;
export interface RemoveUserGroupMembersByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Id of the group whose membership is updated.
     */
    groupId: string;
    /**
  * The account ID of the user. The accountId uniquely identifies the user across all Atlassian products.
  For example, `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`.
  */
    accountId?: string;
}
export declare type RemoveUserGroupMembersByIdResponseOK = undefined;
export declare type RemoveUserGroupMembersByIdResponseError = undefined;
export interface GetUserGroupMembersByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the group to be queried for its members.
     */
    groupId: string;
    /**
     * The starting index of the returned users.
     */
    start?: number;
    /**
  * The maximum number of users to return per page.
  Note, this may be restricted by fixed system limits.
  */
    limit?: number;
    /**
  * Whether to include total size parameter in the results.
  Note, fetching total size property is an expensive operation; use it if your use case needs this value.
  */
    shouldReturnTotalSize?: boolean;
    /**
  * A multi-value parameter indicating which properties of the user to
  expand.
  
    - `operations` returns the operations that the user is allowed to do.
    - `personalSpace` returns the user's personal space, if it exists.
    - `isExternalCollaborator`(@deprecated) see `isGuest` in response to find out whether the user is a guest.
  */
    expand?: Array<"operations" | "personalSpace" | "isExternalCollaborator">;
}
declare type GetUserGroupMembersByIdResponseOKType = UserArrayAsResponse;
export interface GetUserGroupMembersByIdResponseOK extends GetUserGroupMembersByIdResponseOKType {
}
export declare type GetUserGroupMembersByIdResponseError = undefined;
export {};
//# sourceMappingURL=member.d.ts.map