/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class ConfluenceCloudApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Content = new ContentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Watcher = new WatcherGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.DynamicModule = new DynamicModuleGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.UserGroup = new UserGroupGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.InlineTask = new InlineTaskGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Label = new LabelGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.LongRunningTask = new LongRunningTaskGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Relation = new RelationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Search = new SearchGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Setting = new SettingGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Space = new SpaceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Template = new TemplateGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Theme = new ThemeGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Content, this.Watcher, this.DynamicModule, this.UserGroup, this.InlineTask, this.Label, this.LongRunningTask, this.Relation, this.Search, this.Setting, this.Space, this.Template, this.Theme, this.User);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Content, Watcher, DynamicModule, UserGroup, InlineTask, Label, LongRunningTask, Relation, Search, Setting, Space, Template, Theme, User) {
        this.Content = Content;
        this.Watcher = Watcher;
        this.DynamicModule = DynamicModule;
        this.UserGroup = UserGroup;
        this.InlineTask = InlineTask;
        this.Label = Label;
        this.LongRunningTask = LongRunningTask;
        this.Relation = Relation;
        this.Search = Search;
        this.Setting = Setting;
        this.Space = Space;
        this.Template = Template;
        this.Theme = Theme;
        this.User = User;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content in a Confluence instance.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Content.getContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-get
  * @param options Request options.
  * @deprecated
  */
    async getContent(options) {
        return this.Content.getContent(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new piece of content or publishes an existing draft.
  
  To publish a draft, add the `id` and `status` properties to the body of the request.
  Set the `id` to the ID of the draft and set the `status` to 'current'. When the
  request is sent, a new piece of content will be created and the metadata from the
  draft will be transferred into it.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the
  space that the content will be created in, and permission to view the draft if publishing a draft.
  * Alternative usage: Content.createContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-post
  * @param options Request options.
  * @deprecated
  */
    async createContent(options) {
        return this.Content.createContent(options);
    }
    /**
  * Publishes a shared draft of a page created from a blueprint.
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Alternative usage: Content.publishSharedDraft
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-put
  * @param options Request options.
  */
    async publishSharedDraft(options) {
        return this.Content.publishSharedDraft(options);
    }
    /**
  * Publishes a legacy draft of a page created from a blueprint. Legacy drafts
  will eventually be removed in favor of shared drafts. For now, this method
  works the same as [Publish shared draft](#api-content-blueprint-instance-draftId-put).
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Alternative usage: Content.publishLegacyDraft
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-post
  * @param options Request options.
  */
    async publishLegacyDraft(options) {
        return this.Content.publishLegacyDraft(options);
    }
    /**
  * Returns the list of content that matches a Confluence Query Language
  (CQL) query. For information on CQL, see:
  [Advanced searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Example initial call:
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Alternative usage: Content.searchContentByCQL
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-search-get
  * @param options Request options.
  */
    async searchContentByCql(options) {
        return this.Content.searchContentByCql(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a single piece of content, like a page or a blog post.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Alternative usage: Content.getContentById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-get
  * @param options Request options.
  * @deprecated
  */
    async getContentById(options) {
        return this.Content.getContentById(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Updates a piece of content. Use this method to update the title or body
  of a piece of content, change the status, change the parent page, and more.
  
  Note, updating draft content is currently not supported.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.updateContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-put
  * @param options Request options.
  * @deprecated
  */
    async updateContent(options) {
        return this.Content.updateContent(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Moves a piece of content to the space's trash or purges it from the trash,
  depending on the content's type and status:
  
  - If the content's type is `page`,`blogpost`, or `attachment` and its status is `current`,
  it will be trashed.
  - If the content's type is `page`,`blogpost`, or `attachment` and its status is `trashed`,
  the content will be purged from the trash and deleted permanently. Note,
  you must also set the `status` query parameter to `trashed` in your request.
  - If the content's type is `comment`, it will be deleted
  permanently without being trashed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Delete' permission for the space that the content is in.
  * Alternative usage: Content.deleteContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteContent(options) {
        return this.Content.deleteContent(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the most recent update for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: Permission to view the content.
  * Alternative usage: Content.getContentHistory
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-history-get
  * @param options Request options.
  * @deprecated
  */
    async getContentHistory(options) {
        return this.Content.getContentHistory(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the attachments for a piece of content.
  
  By default, the following objects are expanded: `metadata`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Alternative usage: Content.Attachment.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-get
  * @param options Request options.
  * @deprecated
  */
    async getContentAttachments(options) {
        return this.Content.Attachment.getAttachments(options);
    }
    /**
  * Adds an attachment to a piece of content. If the attachment already exists
  for the content, then the attachment is updated (i.e. a new version of the
  attachment is created).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a piece of
  content (id='123') with a comment and `minorEdits`=true. If the 'example.txt'
  file already exists, it will update it with a new version of the attachment.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X PUT \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Attachment.createOrUpdateAttachment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-put
  * @param options Request options.
  */
    async createOrUpdateContentAttachment(options) {
        return this.Content.Attachment.createOrUpdateAttachment(options);
    }
    /**
  * Adds an attachment to a piece of content. This method only adds a new
  attachment. If you want to update an existing attachment, use
  [Create or update attachments](#api-content-id-child-attachment-put).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a container
  (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    https://myhost/wiki/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Attachment.createAttachment
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-post
  * @param options Request options.
  */
    async createContentAttachment(options) {
        return this.Content.Attachment.createAttachment(options);
    }
    /**
  * Updates the attachment properties, i.e. the non-binary data of an attachment
  like the filename, media-type, comment, and parent container.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Attachment.updateAttachmentProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-put
  * @param options Request options.
  */
    async updateContentAttachmentProperties(options) {
        return this.Content.Attachment.updateAttachmentProperties(options);
    }
    /**
  * Updates the binary data of an attachment, given the attachment ID, and
  optionally the comment and the minor edit field.
  
  This method is essentially the same as [Create or update attachments](#api-content-id-child-attachment-put),
  except that it matches the attachment ID rather than the name.
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command updates an attachment (id='att456') that is attached
  to a piece of content (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment/att456/data
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Attachment.updateAttachmentData
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-data-post
  * @param options Request options.
  */
    async updateContentAttachmentData(options) {
        return this.Content.Attachment.updateAttachmentData(options);
    }
    /**
  * Deprecated, use the [single asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post)
  or the [bulk asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-bulk-tasks-post) instead.
  
  Converts a content body from one format to another format.
  
  Supported conversions:
  
  - storage: view, export_view, styled_view, editor
  - editor: storage
  - view: none
  - export_view: none
  - styled_view: none
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: Content.Body.convertBody
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-to-post
  * @param options Request options.
  * @deprecated
  */
    async convertContentBody(options) {
        return this.Content.Body.convertBody(options);
    }
    /**
  * Converts a content body from one format to another format asynchronously.
  Returns the asyncId for the asynchronous task.
  
  Supported conversions:
  
  - atlas_doc_format: editor, export_view, storage, styled_view, view
  - storage: atlas_doc_format, editor, export_view, styled_view, view
  - editor: storage
  
  No other conversions are supported at the moment.
  Once a conversion is completed, it will be available for 5 minutes at the result endpoint.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: Content.Body.asyncConvertBody
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post
  * @param options Request options.
  */
    async asyncConvertContentBody(options) {
        return this.Content.Body.asyncConvertBody(options);
    }
    /**
  * Returns the asynchronous content body for the corresponding id if the task is complete
  or returns the status of the task.
  
  After the task is completed, the result can be obtained for 5 minutes, or until an identical conversion request is made again,
  with allowCache query param set to false.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Alternative usage: Content.Body.getAsyncConvertResult
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-id-get
  * @param options Request options.
  */
    async getAsyncConvertContentBodyResult(options) {
        return this.Content.Body.getAsyncConvertResult(options);
    }
    /**
  * Returns the body of a macro in storage format, for the given macro ID.
  This includes information like the name of the macro, the body of the macro,
  and any macro parameters. This method is mainly used by Cloud apps.
  
  About the macro ID: When a macro is created in a new version of content,
  Confluence will generate a random ID for it, unless an ID is specified
  (by an app). The macro ID will look similar to this: '50884bd9-0cb8-41d5-98be-f80943c14f96'.
  The ID is then persisted as new versions of content are created, and is
  only modified by Confluence if there are conflicting IDs.
  
  For Forge macros, the value for macro ID is the "local ID" of that particular ADF node.
  This value can be retrieved either client-side by calling view.getContext() and accessing "localId"
  on the resulting object, or server-side by examining the "local-id" parameter node inside the "parameters" node.
  
  Note that there are other attributes named "local-id", but only this particular one is used to store the macro ID.
  
  Example:
  <ac:adf-node type="extension">
    <ac:adf-attribute key="extension-type">com.atlassian.ecosystem</ac:adf-attribute>
    <ac:adf-attribute key="parameters">
        <ac:adf-parameter key="local-id">e9c4aa10-73fa-417c-888d-48c719ae4165</ac:adf-parameter>
    </ac:adf-parameter>
  </ac:adf-node>
  
  Note, to preserve backwards compatibility this resource will also match on
  the hash of the macro body, even if a macro ID is found. This check will
  eventually become redundant, as macro IDs are generated for pages and
  transparently propagate out to all instances.
  
  This backwards compatibility logic does not apply to Forge macros; those
  can only be retrieved by their ID.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content that the macro is in.
  * Alternative usage: Content.Body.Macro.getMacroById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---macro-body/#api-wiki-rest-api-content-id-history-version-macro-id-macroid-get
  * @param options Request options.
  */
    async getMacroBodyById(options) {
        return this.Content.Body.Macro.getMacroById(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a map of the direct children of a piece of content. A piece of content
  has different types of child content, depending on its type. These are
  the default parent-child content type relationships:
  
  - `page`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: child content is `comment`, `attachment`
  - `attachment`: child content is `comment`
  - `comment`: child content is `attachment`
  
  Apps can override these default relationships. Apps can also introduce
  new content types that create new parent-child content relationships.
  
  Note, the map will always include all child content types that are valid
  for the content. However, if the content has no instances of a child content
  type, the map will contain an empty array for that child content type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Alternative usage: Content.Children.getChildren
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-child-get
  * @param options Request options.
  * @deprecated
  */
    async getContentChildren(options) {
        return this.Content.Children.getChildren(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all children of a given type, for a piece of content.
  A piece of content has different types of child content, depending on its type:
  
  - `page`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: child content is `comment`, `attachment`
  - `attachment`: child content is `comment`
  - `comment`: child content is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  Note, this method only returns direct children. To return children at all
  levels, use [Get descendants by type](#api-content-id-descendant-type-get).
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Alternative usage: Content.Children.getChildrenByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-child-type-get
  * @param options Request options.
  * @deprecated
  */
    async getContentChildrenByType(options) {
        return this.Content.Children.getChildrenByType(options);
    }
    /**
  * Move a page to a new location relative to a target page:
  
  * `before` - move the page under the same parent as the target, before the target in the list of children
  * `after` - move the page under the same parent as the target, after the target in the list of children
  * `append` - move the page to be a child of the target
  
  Caution: This API can move pages to the top level of a space. Top-level pages are difficult to find in the UI
  because they do not show up in the page tree display. To avoid this, never use `before` or `after` positions
  when the `targetId` is a top-level page.
  * Alternative usage: Content.Move.movePageToNewLocationRelativeToTargetPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-pageid-move-position-targetid-put
  * @param options Request options.
  */
    async movePageToNewLocationRelativeToTargetPage(options) {
        return this.Content.Move.movePageToNewLocationRelativeToTargetPage(options);
    }
    /**
  * Returns a map of the descendants of a piece of content. This is similar
  to [Get content children](#api-content-id-child-get), except that this
  method returns child pages at all levels, rather than just the direct
  child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  The map will always include all descendant types that are valid for the content.
  However, if the content has no instances of a descendant type, the map will
  contain an empty array for that descendant type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Alternative usage: Content.Descendant.getDescendants
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-get
  * @param options Request options.
  * @deprecated
  */
    async getContentDescendants(options) {
        return this.Content.Descendant.getDescendants(options);
    }
    /**
  * Returns all descendants of a given type, for a piece of content. This is
  similar to [Get content children by type](#api-content-id-child-type-get),
  except that this method returns child pages at all levels, rather than just
  the direct child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Alternative usage: Content.Descendant.getDescendantsByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-type-get
  * @param options Request options.
  * @deprecated
  */
    async getContentDescendantsByType(options) {
        return this.Content.Descendant.getDescendantsByType(options);
    }
    /**
  * Copy page hierarchy allows the copying of an entire hierarchy of pages and their associated properties, permissions and attachments.
   The id path parameter refers to the content id of the page to copy, and the new parent of this copied page is defined using the destinationPageId in the request body.
   The titleOptions object defines the rules of renaming page titles during the copy;
   for example, search and replace can be used in conjunction to rewrite the copied page titles.
  
   Response example:
   <pre><code>
   {
        "id" : "1180606",
        "links" : {
             "status" : "/rest/api/longtask/1180606"
        }
   }
   </code></pre>
   Use the /longtask/<taskId> REST API to get the copy task status.
  * Alternative usage: Content.Copy.copyPageHierarchy
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-pagehierarchy-copy-post
  * @param options Request options.
  */
    async copyPageHierarchy(options) {
        return this.Content.Copy.copyPageHierarchy(options);
    }
    /**
  * Copies a single page and its associated properties, permissions, attachments, and custom contents.
   The `id` path parameter refers to the content ID of the page to copy. The target of the page to be copied
   is defined using the `destination` in the request body and can be one of the following types.
  
    - `space`: page will be copied to the specified space as a root page on the space
    - `parent_page`: page will be copied as a child of the specified parent page
    - `parent_content`: page will be copied as a child of the specified parent content
    - `existing_page`: page will be copied and replace the specified page
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the space that the content will be copied in and permission to update the content if copying to an `existing_page`.
  * Alternative usage: Content.Copy.copySinglePage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-copy-post
  * @param options Request options.
  */
    async copySinglePage(options) {
        return this.Content.Copy.copySinglePage(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the comments on a piece of content.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Alternative usage: Content.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-comments/#api-wiki-rest-api-content-id-child-comment-get
  * @param options Request options.
  * @deprecated
  */
    async getContentComments(options) {
        return this.Content.Comment.getComments(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the labels on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space and permission to view the content if it is a page.
  * Alternative usage: Content.Label.getLabels
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-get
  * @param options Request options.
  * @deprecated
  */
    async getContentLabels(options) {
        return this.Content.Label.getLabels(options);
    }
    /**
  * Adds labels to a piece of content. Does not modify the existing labels.
  
  Notes:
  
  - Labels can also be added when creating content ([Create content](#api-content-post)).
  - Labels can be updated when updating content ([Update content](#api-content-id-put)).
  This will delete the existing labels and replace them with the labels in
  the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Label.addLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-post
  * @param options Request options.
  */
    async addContentLabel(options) {
        return this.Content.Label.addLabel(options);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content](#api-content-id-label-label-delete)
  except that the label name is specified via a query parameter.
  
  Use this method if the label name has "/" characters, as
  [Remove label from content using query parameter](#api-content-id-label-delete)
  does not accept "/" characters for the label name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Label.removeLabelWithQueryParameter
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-delete
  * @param options Request options.
  */
    async removeContentLabelWithQueryParameter(options) {
        return this.Content.Label.removeLabelWithQueryParameter(options);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content using query parameter](#api-content-id-label-delete)
  except that the label name is specified via a path parameter.
  
  Use this method if the label name does not have "/" characters, as the path
  parameter does not accept "/" characters for security reasons. Otherwise,
  use [Remove label from content using query parameter](#api-content-id-label-delete).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Label.removeLabel
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-label-delete
  * @param options Request options.
  */
    async removeContentLabel(options) {
        return this.Content.Label.removeLabel(options);
    }
    /**
  * Returns the properties for a piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it is a page.
  * Alternative usage: Content.Property.getProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-get
  * @param options Request options.
  * @deprecated
  */
    async getContentProperties(options) {
        return this.Content.Property.getProperties(options);
    }
    /**
  * Creates a property for an existing piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  This is the same as [Create content property for key](#api-content-id-property-key-post)
  except that the key is specified in the request body instead of as a
  path parameter.
  
  Content properties can also be added when creating a new piece of content
  by including them in the `metadata.properties` of the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Property.createProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-post
  * @param options Request options.
  * @deprecated
  */
    async createContentProperty(options) {
        return this.Content.Property.createProperty(options);
    }
    /**
  * Returns a content property for a piece of content. For more information, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it is a page.
  * Alternative usage: Content.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-get
  * @param options Request options.
  * @deprecated
  */
    async getContentProperty(options) {
        return this.Content.Property.getProperty(options);
    }
    /**
  * Updates an existing content property. This method will also create a new
  property for a piece of content, if the property key does not exist and
  the property version is 1. For more information about content properties, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Property.updateProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-put
  * @param options Request options.
  * @deprecated
  */
    async updateContentProperty(options) {
        return this.Content.Property.updateProperty(options);
    }
    /**
  * Creates a property for an existing piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  This is the same as [Create content property](#api-content-id-property-post)
  except that the key is specified as a path parameter instead of in the
  request body.
  
  Content properties can also be added when creating a new piece of content
  by including them in the `metadata.properties` of the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Property.createPropertyForKey
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-post
  * @param options Request options.
  * @deprecated
  */
    async createContentPropertyForKey(options) {
        return this.Content.Property.createPropertyForKey(options);
    }
    /**
  * Deletes a content property. For more information about content properties, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteContentProperty(options) {
        return this.Content.Property.deleteProperty(options);
    }
    /**
  * Returns the restrictions on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: Content.Restriction.getRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-get
  * @param options Request options.
  */
    async getContentRestrictions(options) {
        return this.Content.Restriction.getRestrictions(options);
    }
    /**
  * Updates restrictions for a piece of content. This removes the existing
  restrictions and replaces them with the restrictions in the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.updateRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-put
  * @param options Request options.
  */
    async updateContentRestrictions(options) {
        return this.Content.Restriction.updateRestrictions(options);
    }
    /**
  * Adds restrictions to a piece of content. Note, this does not change any
  existing restrictions on the content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.addRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-post
  * @param options Request options.
  */
    async addContentRestrictions(options) {
        return this.Content.Restriction.addRestrictions(options);
    }
    /**
  * Removes all restrictions (read and update) on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.deleteRestrictions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-delete
  * @param options Request options.
  */
    async deleteContentRestrictions(options) {
        return this.Content.Restriction.deleteRestrictions(options);
    }
    /**
  * Returns restrictions on a piece of content by operation. This method is
  similar to [Get restrictions](#api-content-id-restriction-get) except that
  the operations are properties of the return object, rather than items in
  a results array.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: Content.Restriction.getRestrictionsByOperation
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-get
  * @param options Request options.
  */
    async getContentRestrictionsByOperation(options) {
        return this.Content.Restriction.getRestrictionsByOperation(options);
    }
    /**
  * Returns the restictions on a piece of content for a given operation (read
  or update).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: Content.Restriction.getRestrictionsForOperation
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-get
  * @param options Request options.
  */
    async getContentRestrictionsForOperation(options) {
        return this.Content.Restriction.getRestrictionsForOperation(options);
    }
    /**
  * Returns whether the specified content restriction applies to a group.
  For example, if a page with `id=123` has a `read` restriction for the `123456` group id,
  the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/byGroupId/123456`
  
  Note that a response of `true` does not guarantee that the group can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: Content.Restriction.Group.getGroupStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-get
  * @param options Request options.
  */
    async getContentRestrictionGroupStatus(options) {
        return this.Content.Restriction.Group.getGroupStatus(options);
    }
    /**
  * Adds a group to a content restriction by Group Id. That is, grant read or update
  permission to the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.Group.addGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-put
  * @param options Request options.
  */
    async addContentRestrictionGroup(options) {
        return this.Content.Restriction.Group.addGroup(options);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.Group.removeGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-delete
  * @param options Request options.
  */
    async removeContentRestrictionGroup(options) {
        return this.Content.Restriction.Group.removeGroup(options);
    }
    /**
  * Returns whether the specified content restriction applies to a user.
  For example, if a page with `id=123` has a `read` restriction for a user with an account ID of
  `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`, the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/user?accountId=384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`
  
  Note that a response of `true` does not guarantee that the user can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Alternative usage: Content.Restriction.User.getUserStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-get
  * @param options Request options.
  */
    async getContentRestrictionUserStatus(options) {
        return this.Content.Restriction.User.getUserStatus(options);
    }
    /**
  * Adds a user to a content restriction. That is, grant read or update
  permission to the user for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.User.addUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-put
  * @param options Request options.
  */
    async addContentRestrictionUser(options) {
        return this.Content.Restriction.User.addUser(options);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Alternative usage: Content.Restriction.User.removeUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-delete
  * @param options Request options.
  */
    async removeContentRestrictionUser(options) {
        return this.Content.Restriction.User.removeUser(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the versions for a piece of content in descending order.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Alternative usage: Content.Version.getVersions
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-get
  * @param options Request options.
  * @deprecated
  */
    async getContentVersions(options) {
        return this.Content.Version.getVersions(options);
    }
    /**
  * Restores a historical version to be the latest version. That is, a new version
  is created with the content of the historical version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Version.restoreVersion
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-post
  * @param options Request options.
  */
    async restoreContentVersion(options) {
        return this.Content.Version.restoreVersion(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a version for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Alternative usage: Content.Version.getVersion
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-get
  * @param options Request options.
  * @deprecated
  */
    async getContentVersion(options) {
        return this.Content.Version.getVersion(options);
    }
    /**
  * Delete a historical version. This does not delete the changes made to the
  content in that version, rather the changes for the deleted version are
  rolled up into the next version. Note, you cannot delete the current version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Alternative usage: Content.Version.deleteVersion
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-delete
  * @param options Request options.
  */
    async deleteContentVersion(options) {
        return this.Content.Version.deleteVersion(options);
    }
    /**
  * Returns the watches for a page. A user that watches a page will receive
  receive notifications when the page is updated.
  
  If you want to manage watches for a page, use the following `user` methods:
  
  - [Get content watch status for user](#api-user-watch-content-contentId-get)
  - [Add content watch](#api-user-watch-content-contentId-post)
  - [Remove content watch](#api-user-watch-content-contentId-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.getWatchesForPage
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-child-created-get
  * @param options Request options.
  */
    async getWatchesForPage(options) {
        return this.Watcher.getWatchesForPage(options);
    }
    /**
  * Returns all space watches for the space that the content is in. A user that
  watches a space will receive receive notifications when any content in the
  space is updated.
  
  If you want to manage watches for a space, use the following `user` methods:
  
  - [Get space watch status for user](#api-user-watch-space-spaceKey-get)
  - [Add space watch](#api-user-watch-space-spaceKey-post)
  - [Remove space watch](#api-user-watch-space-spaceKey-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.getWatchesForSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-created-get
  * @param options Request options.
  */
    async getWatchesForSpace(options) {
        return this.Watcher.getWatchesForSpace(options);
    }
    /**
     * Returns a list of watchers of a space
     * Alternative usage: Watcher.getSpaceWatchers
     * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-space-spacekey-watch-get
     * @param options Request options.
     */
    async getSpaceWatchers(options) {
        return this.Watcher.getSpaceWatchers(options);
    }
    /**
  * Returns whether a user is watching a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Content.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-get
  * @param options Request options.
  */
    async getContentWatcherStatus(options) {
        return this.Watcher.Content.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a piece of content. Choose the user by doing
  one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Content.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-post
  * @param options Request options.
  */
    async addContentWatcher(options) {
        return this.Watcher.Content.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Content.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-delete
  * @param options Request options.
  */
    async removeContentWatcher(options) {
        return this.Watcher.Content.removeWatcher(options);
    }
    /**
  * Returns whether a user is watching a label. Choose the user by doing one
  of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Label.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-get
  * @param options Request options.
  */
    async getLabelWatcherStatus(options) {
        return this.Watcher.Label.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a label. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Label.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-post
  * @param options Request options.
  */
    async addLabelWatcher(options) {
        return this.Watcher.Label.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a label. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Label.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-delete
  * @param options Request options.
  */
    async removeLabelWatcher(options) {
        return this.Watcher.Label.removeWatcher(options);
    }
    /**
  * Returns whether a user is watching a space. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Space.getWatcherStatus
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-get
  * @param options Request options.
  */
    async getSpaceWatcherStatus(options) {
        return this.Watcher.Space.getWatcherStatus(options);
    }
    /**
  * Adds a user as a watcher to a space. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Space.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-post
  * @param options Request options.
  */
    async addSpaceWatcher(options) {
        return this.Watcher.Space.addWatcher(options);
    }
    /**
  * Removes a user as a watcher from a space. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Watcher.Space.removeWatcher
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-delete
  * @param options Request options.
  */
    async removeSpaceWatcher(options) {
        return this.Watcher.Space.removeWatcher(options);
    }
    /**
  * Returns all modules registered dynamically by the calling app.
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Alternative usage: DynamicModule.getModules
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-get
  * @param options Request options.
  */
    async getModules(options) {
        return this.DynamicModule.getModules(options);
    }
    /**
  * Registers a list of modules. For the list of modules that support dynamic registration, see [Dynamic modules](https://developer.atlassian.com/cloud/confluence/dynamic-modules/).
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Alternative usage: DynamicModule.registerModules
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-post
  * @param options Request options.
  */
    async registerModules(options) {
        return this.DynamicModule.registerModules(options);
    }
    /**
  * Remove all or a list of modules registered by the calling app.
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Alternative usage: DynamicModule.removeModules
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-delete
  * @param options Request options.
  */
    async removeModules(options) {
        return this.DynamicModule.removeModules(options);
    }
    /**
  * Returns all user groups. The returned groups are ordered alphabetically in
  ascending order by group name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: UserGroup.getUserGroups
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-get
  * @param options Request options.
  */
    async getUserGroups(options) {
        return this.UserGroup.getUserGroups(options);
    }
    /**
  * Creates a new user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: UserGroup.createUserGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-post
  * @param options Request options.
  */
    async createUserGroup(options) {
        return this.UserGroup.createUserGroup(options);
    }
    /**
  * Delete user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: UserGroup.deleteUserGroup
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-delete
  * @param options Request options.
  */
    async deleteUserGroup(options) {
        return this.UserGroup.deleteUserGroup(options);
    }
    /**
  * Returns a user group for a given group id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: UserGroup.getUserGroupById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-get
  * @param options Request options.
  */
    async getUserGroupById(options) {
        return this.UserGroup.getUserGroupById(options);
    }
    /**
  * Adds a user as a member in a group represented by its groupId
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: UserGroup.Member.addMemberById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-post
  * @param options Request options.
  */
    async addUserGroupMembersById(options) {
        return this.UserGroup.Member.addMemberById(options);
    }
    /**
  * Remove user as a member from a group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Alternative usage: UserGroup.Member.removeMemberById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-delete
  * @param options Request options.
  */
    async removeUserGroupMembersById(options) {
        return this.UserGroup.Member.removeMemberById(options);
    }
    /**
  * Returns the users that are members of a group.
  
  Use updated Get group API
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: UserGroup.Member.getMembersById
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-groupid-membersbygroupid-get
  * @param options Request options.
  */
    async getUserGroupMembersById(options) {
        return this.UserGroup.Member.getMembersById(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns inline tasks based on the search query.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only tasks
  in contents that the user has permission to view are returned.
  * Alternative usage: InlineTask.getInlineTasksBasedOnSearchParameters
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-inline-tasks/#api-wiki-rest-api-inlinetasks-search-get
  * @param options Request options.
  * @deprecated
  */
    async getInlineTasksBasedOnSearchParameters(options) {
        return this.InlineTask.getInlineTasksBasedOnSearchParameters(options);
    }
    /**
  * Returns label information and a list of contents associated with the label.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only contents
  that the user is permitted to view is returned.
  * Alternative usage: Label.getInfo
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-label-info/#api-wiki-rest-api-label-get
  * @param options Request options.
  */
    async getLabelInfo(options) {
        return this.Label.getInfo(options);
    }
    /**
  * Returns information about all active long-running tasks (e.g. space export),
  such as how long each task has been running and the percentage of each task
  that has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: LongRunningTask.getLongRunningTasks
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-get
  * @param options Request options.
  */
    async getLongRunningTasks(options) {
        return this.LongRunningTask.getLongRunningTasks(options);
    }
    /**
  * Returns information about an active long-running task (e.g. space export),
  such as how long it has been running and the percentage of the task that
  has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: LongRunningTask.getLongRunningTask
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-id-get
  * @param options Request options.
  */
    async getLongRunningTask(options) {
        return this.LongRunningTask.getLongRunningTask(options);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all content that the current user
  has an 'ignore' relationship with:
  `GET /wiki/rest/api/relation/ignore/from/user/current/to/content`
  Note, 'ignore' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: Relation.findTargetEntitiesRelatedToSourceEntity
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-get
  * @param options Request options.
  */
    async findTargetEntitiesRelatedToSourceEntity(options) {
        return this.Relation.findTargetEntitiesRelatedToSourceEntity(options);
    }
    /**
  * Find whether a particular type of relationship exists from a source
  entity to a target entity. Note, relationships are one way.
  
  For example, you can use this method to find whether the current user has
  selected a particular page as a favorite (i.e. 'save for later'):
  `GET /wiki/rest/api/relation/favourite/from/user/current/to/content/123`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: Relation.findRelationshipFromSourceToTarget
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-get
  * @param options Request options.
  */
    async findRelationshipFromSourceToTarget(options) {
        return this.Relation.findRelationshipFromSourceToTarget(options);
    }
    /**
  * Creates a relationship between two entities (user, space, content). The
  'favourite' relationship is supported by default, but you can use this method
  to create any type of relationship between two entities.
  
  For example, the following method creates a 'sibling' relationship between
  two pieces of content:
  `PUT /wiki/rest/api/relation/sibling/from/content/123/to/content/456`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Relation.createRelationship
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put
  * @param options Request options.
  */
    async createRelationship(options) {
        return this.Relation.createRelationship(options);
    }
    /**
  * Deletes a relationship between two entities (user, space, content).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  For favourite relationships, the current user can only delete their own
  favourite relationships. A space administrator can delete favourite
  relationships for any user.
  * Alternative usage: Relation.deleteRelationship
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-delete
  * @param options Request options.
  */
    async deleteRelationship(options) {
        return this.Relation.deleteRelationship(options);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all users that have a 'collaborator'
  relationship to a piece of content with an ID of '1234':
  `GET /wiki/rest/api/relation/collaborator/to/content/1234/from/user`
  Note, 'collaborator' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Alternative usage: Relation.findSourceEntitiesRelatedToTargetEntity
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-to-targettype-targetkey-from-sourcetype-get
  * @param options Request options.
  */
    async findSourceEntitiesRelatedToTargetEntity(options) {
        return this.Relation.findSourceEntitiesRelatedToTargetEntity(options);
    }
    /**
  * Searches for content using the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  **Note that CQL input queries submitted through the `/wiki/rest/api/search` endpoint no longer support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.**
  See this [deprecation notice](https://developer.atlassian.com/cloud/confluence/deprecation-notice-search-api/) for more details.
  
  Example initial call:
  ```
  /wiki/rest/api/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the entities. Note, only entities that the user has
  permission to view will be returned.
  * Alternative usage: Search.searchContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-get
  * @param options Request options.
  */
    async searchContent(options) {
        return this.Search.searchContent(options);
    }
    /**
  * Searches for users using user-specific queries from the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Note that CQL input queries submitted through the `/wiki/rest/api/search/user` endpoint only support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.
  
  Note that some user fields may be set to null depending on the user's privacy settings.
  These are: email, profilePicture, displayName, and timeZone.
  * Alternative usage: Search.searchUsers
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-user-get
  * @param options Request options.
  */
    async searchUsers(options) {
        return this.Search.searchUsers(options);
    }
    /**
  * Returns the look and feel settings for the site or a single space. This
  includes attributes such as the color scheme, padding, and border radius.
  
  The look and feel settings for a space can be inherited from the global
  look and feel settings or provided by a theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  None
  * Alternative usage: Setting.getLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-get
  * @param options Request options.
  */
    async getLookAndFeelSettings(options) {
        return this.Setting.getLookAndFeelSettings(options);
    }
    /**
  * Updates the look and feel settings for the site or for a single space.
  If custom settings exist, they are updated. If no custom settings exist,
  then a set of custom settings is created.
  
  Note, if a theme is selected for a space, the space look and feel settings
  are provided by the theme and cannot be overridden.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Setting.updateLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-post
  * @param options Request options.
  */
    async updateLookAndFeelSettings(options) {
        return this.Setting.updateLookAndFeelSettings(options);
    }
    /**
  * Resets the custom look and feel settings for the site or a single space.
  This changes the values of the custom settings to be the same as the
  default settings. It does not change which settings (default or custom)
  are selected. Note, the default space settings are inherited from the
  current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Setting.resetLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-delete
  * @param options Request options.
  */
    async resetLookAndFeelSettings(options) {
        return this.Setting.resetLookAndFeelSettings(options);
    }
    /**
  * Sets the look and feel settings to either the default settings or the
  custom settings, for the site or a single space. Note, the default
  space settings are inherited from the current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Setting.setLookAndFeelSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-selected-put
  * @param options Request options.
  * @deprecated
  */
    async setLookAndFeelSettings(options) {
        return this.Setting.setLookAndFeelSettings(options);
    }
    /**
  * Returns the system information for the Confluence Cloud tenant. This
  information is used by Atlassian.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: Setting.getSystemInfo
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-systeminfo-get
  * @param options Request options.
  */
    async getSystemInfo(options) {
        return this.Setting.getSystemInfo(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all spaces. The returned spaces are ordered alphabetically in
  ascending order by space key.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Note, the returned list will only contain spaces that the current user
  has permission to view.
  * Alternative usage: Space.getSpaces
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaces(options) {
        return this.Space.getSpaces(options);
    }
    /**
  * Creates a new space. Note, currently you cannot set space labels when
  creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Alternative usage: Space.createSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-post
  * @param options Request options.
  */
    async createSpace(options) {
        return this.Space.createSpace(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a space. This includes information like the name, description,
  and permissions, but not the content in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Alternative usage: Space.getSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-get
  * @param options Request options.
  * @deprecated
  */
    async getSpace(options) {
        return this.Space.getSpace(options);
    }
    /**
  * Updates the name, description, or homepage of a space.
  
  -   For security reasons, permissions cannot be updated via the API and
  must be changed via the user interface instead.
  -   Currently you cannot set space labels when updating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Space.updateSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-put
  * @param options Request options.
  */
    async updateSpace(options) {
        return this.Space.updateSpace(options);
    }
    /**
  * Permanently deletes a space without sending it to the trash. Note, the space will be deleted in a long running task.
  Therefore, the space may not be deleted yet when this method has
  returned. Clients should poll the status link that is returned in the
  response until the task completes.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Space.deleteSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-delete
  * @param options Request options.
  */
    async deleteSpace(options) {
        return this.Space.deleteSpace(options);
    }
    /**
  * Creates a new space that is only visible to the creator. This method is
  the same as the [Create space](#api-space-post) method with permissions
  set to the current user only. Note, currently you cannot set space
  labels when creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Alternative usage: Space.Private.createSpace
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-private-post
  * @param options Request options.
  */
    async createPrivateSpace(options) {
        return this.Space.Private.createSpace(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content in a space. The returned content is grouped by type
  (pages then blogposts), then ordered by content ID in ascending order.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space. Note, the returned list will only
  contain content that the current user has permission to view.
  * Alternative usage: Space.Content.getContent
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-content-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaceContent(options) {
        return this.Space.Content.getContent(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content of a given type, in a space. The returned content is
  ordered by content ID in ascending order.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space. Note, the returned list will only
  contain content that the current user has permission to view.
  * Alternative usage: Space.Content.getContentByType
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-content-type-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaceContentByType(options) {
        return this.Space.Content.getContentByType(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all properties for the given space. Space properties are a key-value storage associated with a space.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Alternative usage: Space.Property.getProperties
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaceProperties(options) {
        return this.Space.Property.getProperties(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Alternative usage: Space.Property.createProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-post
  * @param options Request options.
  * @deprecated
  */
    async createSpaceProperty(options) {
        return this.Space.Property.createProperty(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Alternative usage: Space.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaceProperty(options) {
        return this.Space.Property.getProperty(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Updates a space property. Note, you cannot update the key of a space
  property, only the value.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Alternative usage: Space.Property.updateProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-put
  * @param options Request options.
  * @deprecated
  */
    async updateSpaceProperty(options) {
        return this.Space.Property.updateProperty(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new space property. This is the same as `POST
  /wiki/rest/api/space/{spaceKey}/property` but the key for the property is passed as a
  path parameter, rather than in the request body.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Alternative usage: Space.Property.createPropertyForKey
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-post
  * @param options Request options.
  * @deprecated
  */
    async createSpacePropertyForKey(options) {
        return this.Space.Property.createPropertyForKey(options);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Deletes a space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Alternative usage: Space.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteSpaceProperty(options) {
        return this.Space.Property.deleteProperty(options);
    }
    /**
  * Returns the settings of a space. Currently only the
  `routeOverrideEnabled` setting can be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Alternative usage: Space.Setting.getSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-get
  * @param options Request options.
  */
    async getSpaceSettings(options) {
        return this.Space.Setting.getSettings(options);
    }
    /**
  * Updates the settings for a space. Currently only the
  `routeOverrideEnabled` setting can be updated.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Space.Setting.updateSettings
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-put
  * @param options Request options.
  */
    async updateSpaceSettings(options) {
        return this.Space.Setting.updateSettings(options);
    }
    /**
  * Updates a content template. Note, blueprint templates cannot be updated
  via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to update a space template or 'Confluence Administrator'
  global permission to update a global template.
  * Alternative usage: Template.updateContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-put
  * @param options Request options.
  */
    async updateContentTemplate(options) {
        return this.Template.updateContentTemplate(options);
    }
    /**
  * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to create a space template or 'Confluence Administrator'
  global permission to create a global template.
  * Alternative usage: Template.createContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-post
  * @param options Request options.
  */
    async createContentTemplate(options) {
        return this.Template.createContentTemplate(options);
    }
    /**
  * Returns all templates provided by blueprints. Use this method to retrieve
  all global blueprint templates or all blueprint templates in a space.
  
  Note, all global blueprints are inherited by each space. Space blueprints
  can be customised without affecting the global blueprints.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view blueprints for the space and permission
  to access the Confluence site ('Can use' global permission) to view global blueprints.
  * Alternative usage: Template.getBlueprintTemplates
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-blueprint-get
  * @param options Request options.
  */
    async getBlueprintTemplates(options) {
        return this.Template.getBlueprintTemplates(options);
    }
    /**
  * Returns all content templates. Use this method to retrieve all global
  content templates or all content templates in a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Alternative usage: Template.getContentTemplates
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-page-get
  * @param options Request options.
  */
    async getContentTemplates(options) {
        return this.Template.getContentTemplates(options);
    }
    /**
  * Returns a content template. This includes information about template,
  like the name, the space or blueprint that the template is in, the body
  of the template, and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Alternative usage: Template.getContentTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-get
  * @param options Request options.
  */
    async getContentTemplate(options) {
        return this.Template.getContentTemplate(options);
    }
    /**
  * Deletes a template. This results in different actions depending on the
  type of template:
  
  - If the template is a content template, it is deleted.
  - If the template is a modified space-level blueprint template, it reverts
  to the template inherited from the global-level blueprint template.
  - If the template is a modified global-level blueprint template, it reverts
  to the default global-level blueprint template.
  
   Note, unmodified blueprint templates cannot be deleted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
          'Admin' permission for the space to delete a space template or 'Confluence Administrator'
          global permission to delete a global template.
  * Alternative usage: Template.removeTemplate
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-delete
  * @param options Request options.
  */
    async removeTemplate(options) {
        return this.Template.removeTemplate(options);
    }
    /**
  * Returns all themes, not including the default theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: Theme.getThemes
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-get
  * @param options Request options.
  */
    async getThemes(options) {
        return this.Theme.getThemes(options);
    }
    /**
  * Returns the globally assigned theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: Theme.getGlobalTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-selected-get
  * @param options Request options.
  */
    async getGlobalTheme(options) {
        return this.Theme.getGlobalTheme(options);
    }
    /**
  * Returns a theme. This includes information about the theme name,
  description, and icon.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Alternative usage: Theme.getTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-themekey-get
  * @param options Request options.
  */
    async getTheme(options) {
        return this.Theme.getTheme(options);
    }
    /**
  * Returns the theme selected for a space, if one is set. If no space
  theme is set, this means that the space is inheriting the global look
  and feel settings.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Alternative usage: Theme.getSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-get
  * @param options Request options.
  */
    async getSpaceTheme(options) {
        return this.Theme.getSpaceTheme(options);
    }
    /**
  * Sets the theme for a space. Note, if you want to reset the space theme to
  the default Confluence theme, use the 'Reset space theme' method instead
  of this method.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Theme.setSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-put
  * @param options Request options.
  */
    async setSpaceTheme(options) {
        return this.Theme.setSpaceTheme(options);
    }
    /**
  * Resets the space theme. This means that the space will inherit the
  global look and feel settings
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Alternative usage: Theme.resetSpaceTheme
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-delete
  * @param options Request options.
  */
    async resetSpaceTheme(options) {
        return this.Theme.resetSpaceTheme(options);
    }
    /**
  * Returns a user. This includes information about the user, such as the
  display name, account ID, profile picture, and more. The information returned may be
  restricted by the user's profile visibility settings.
  
  **Note:** to add, edit, or delete users in your organization, see the
  [user management REST API](/cloud/admin/user-management/about/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-get
  * @param options Request options.
  */
    async getUser(options) {
        return this.User.getUser(options);
    }
    /**
  * Returns information about how anonymous users are represented, like the
  profile picture and display name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getAnonymousUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-anonymous-get
  * @param options Request options.
  */
    async getAnonymousUser(options) {
        return this.User.getAnonymousUser(options);
    }
    /**
  * Returns the currently logged-in user. This includes information about
  the user, like the display name, userKey, account ID, profile picture,
  and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getCurrentUser
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-current-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        return this.User.getCurrentUser(options);
    }
    /**
  * Returns the groups that a user is a member of.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getGroupsWhereUserMember
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-memberof-get
  * @param options Request options.
  */
    async getGroupsWhereUserMember(options) {
        return this.User.getGroupsWhereUserMember(options);
    }
    /**
  * Returns user details for the ids provided in the request.
  Currently this API returns a maximum of 100 results.
  If more than 100 account ids are passed in, then the first 100 will be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getUsersWithIds
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-bulk-get
  * @param options Request options.
  */
    async getUsersWithIds(options) {
        return this.User.getUsersWithIds(options);
    }
    /**
  * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getUserEmail
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-get
  * @param options Request options.
  */
    async getUserEmail(options) {
        return this.User.getUserEmail(options);
    }
    /**
  * Returns a user's email address regardless of the user’s profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  Any accounts which are not available will not be included in the result.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Alternative usage: User.getUserEmails
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-bulk-get
  * @param options Request options.
  */
    async getUserEmails(options) {
        return this.User.getUserEmails(options);
    }
}
class ContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new ContentAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Body = new ContentBodyGroup(implementation, this.getGlobalErrorStrategy);
        this.Children = new ContentChildrenGroup(implementation, this.getGlobalErrorStrategy);
        this.Move = new ContentMoveGroup(implementation, this.getGlobalErrorStrategy);
        this.Descendant = new ContentDescendantGroup(implementation, this.getGlobalErrorStrategy);
        this.Copy = new ContentCopyGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new ContentCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new ContentLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new ContentPropertyGroup(implementation, this.getGlobalErrorStrategy);
        this.Restriction = new ContentRestrictionGroup(implementation, this.getGlobalErrorStrategy);
        this.Version = new ContentVersionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content in a Confluence instance.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-get
  * @param options Request options.
  * @deprecated
  */
    async getContent(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new piece of content or publishes an existing draft.
  
  To publish a draft, add the `id` and `status` properties to the body of the request.
  Set the `id` to the ID of the draft and set the `status` to 'current'. When the
  request is sent, a new piece of content will be created and the metadata from the
  draft will be transferred into it.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the
  space that the content will be created in, and permission to view the draft if publishing a draft.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-post
  * @param options Request options.
  * @deprecated
  */
    async createContent(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Publishes a shared draft of a page created from a blueprint.
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-put
  * @param options Request options.
  */
    async publishSharedDraft(options) {
        const { body, headers, errorStrategy, draftId, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/blueprint/instance/${encodeURIComponent(draftId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Publishes a legacy draft of a page created from a blueprint. Legacy drafts
  will eventually be removed in favor of shared drafts. For now, this method
  works the same as [Publish shared draft](#api-content-blueprint-instance-draftId-put).
  
  By default, the following objects are expanded: `body.storage`, `history`, `space`, `version`, `ancestors`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the draft and 'Add' permission for the space that
  the content will be created in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-blueprint-instance-draftid-post
  * @param options Request options.
  */
    async publishLegacyDraft(options) {
        const { body, headers, errorStrategy, draftId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/blueprint/instance/${encodeURIComponent(draftId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the list of content that matches a Confluence Query Language
  (CQL) query. For information on CQL, see:
  [Advanced searching using CQL](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Example initial call:
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/content/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Only content that the user has permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-search-get
  * @param options Request options.
  */
    async searchContentByCql(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a single piece of content, like a page or a blog post.
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-get
  * @param options Request options.
  * @deprecated
  */
    async getContentById(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Updates a piece of content. Use this method to update the title or body
  of a piece of content, change the status, change the parent page, and more.
  
  Note, updating draft content is currently not supported.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-put
  * @param options Request options.
  * @deprecated
  */
    async updateContent(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Moves a piece of content to the space's trash or purges it from the trash,
  depending on the content's type and status:
  
  - If the content's type is `page`,`blogpost`, or `attachment` and its status is `current`,
  it will be trashed.
  - If the content's type is `page`,`blogpost`, or `attachment` and its status is `trashed`,
  the content will be purged from the trash and deleted permanently. Note,
  you must also set the `status` query parameter to `trashed` in your request.
  - If the content's type is `comment`, it will be deleted
  permanently without being trashed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Delete' permission for the space that the content is in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteContent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the most recent update for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content/#api-wiki-rest-api-content-id-history-get
  * @param options Request options.
  * @deprecated
  */
    async getContentHistory(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/history`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the attachments for a piece of content.
  
  By default, the following objects are expanded: `metadata`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-get
  * @param options Request options.
  * @deprecated
  */
    async getAttachments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds an attachment to a piece of content. If the attachment already exists
  for the content, then the attachment is updated (i.e. a new version of the
  attachment is created).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a piece of
  content (id='123') with a comment and `minorEdits`=true. If the 'example.txt'
  file already exists, it will update it with a new version of the attachment.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X PUT \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-put
  * @param options Request options.
  */
    async createOrUpdateAttachment(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds an attachment to a piece of content. This method only adds a new
  attachment. If you want to update an existing attachment, use
  [Create or update attachments](#api-content-id-child-attachment-put).
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command attaches a file ('example.txt') to a container
  (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    https://myhost/wiki/rest/api/content/123/child/attachment
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-post
  * @param options Request options.
  */
    async createAttachment(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the attachment properties, i.e. the non-binary data of an attachment
  like the filename, media-type, comment, and parent container.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-put
  * @param options Request options.
  */
    async updateAttachmentProperties(options) {
        const { body, headers, errorStrategy, id, attachmentId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment/${encodeURIComponent(attachmentId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the binary data of an attachment, given the attachment ID, and
  optionally the comment and the minor edit field.
  
  This method is essentially the same as [Create or update attachments](#api-content-id-child-attachment-put),
  except that it matches the attachment ID rather than the name.
  
  Note, you must set a `X-Atlassian-Token: nocheck` header on the request
  for this method, otherwise it will be blocked. This protects against XSRF
  attacks, which is necessary as this method accepts multipart/form-data.
  
  The media type 'multipart/form-data' is defined in [RFC 7578](https://www.ietf.org/rfc/rfc7578.txt).
  Most client libraries have classes that make it easier to implement
  multipart posts, like the [MultipartEntityBuilder](https://hc.apache.org/httpcomponents-client-5.1.x/current/httpclient5/apidocs/)
  Java class provided by Apache HTTP Components.
  
  Note, according to [RFC 7578](https://tools.ietf.org/html/rfc7578#section-4.5),
  in the case where the form data is text,
  the charset parameter for the "text/plain" Content-Type may be used to
  indicate the character encoding used in that part. In the case of this
  API endpoint, the `comment` body parameter should be sent with `type=text/plain`
  and `charset=utf-8` values. This will force the charset to be UTF-8.
  
  Example: This curl command updates an attachment (id='att456') that is attached
  to a piece of content (id='123') with a comment and `minorEdits`=true.
  
  ``` bash
  curl -D- \
    -u admin:admin \
    -X POST \
    -H 'X-Atlassian-Token: nocheck' \
    -F 'file=@"example.txt"' \
    -F 'minorEdit="true"' \
    -F 'comment="Example attachment comment"; type=text/plain; charset=utf-8' \
    http://myhost/rest/api/content/123/child/attachment/att456/data
  ```
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---attachments/#api-wiki-rest-api-content-id-child-attachment-attachmentid-data-post
  * @param options Request options.
  */
    async updateAttachmentData(options) {
        const { headers, errorStrategy, id, attachmentId } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/child/attachment/${encodeURIComponent(attachmentId)}/data`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentBodyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Macro = new ContentBodyMacroGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deprecated, use the [single asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post)
  or the [bulk asynchronous endpoint](https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-bulk-tasks-post) instead.
  
  Converts a content body from one format to another format.
  
  Supported conversions:
  
  - storage: view, export_view, styled_view, editor
  - editor: storage
  - view: none
  - export_view: none
  - styled_view: none
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-to-post
  * @param options Request options.
  * @deprecated
  */
    async convertBody(options) {
        const { body, headers, errorStrategy, to, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/contentbody/convert/${encodeURIComponent(to)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Converts a content body from one format to another format asynchronously.
  Returns the asyncId for the asynchronous task.
  
  Supported conversions:
  
  - atlas_doc_format: editor, export_view, storage, styled_view, view
  - storage: atlas_doc_format, editor, export_view, styled_view, view
  - editor: storage
  
  No other conversions are supported at the moment.
  Once a conversion is completed, it will be available for 5 minutes at the result endpoint.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-to-post
  * @param options Request options.
  */
    async asyncConvertBody(options) {
        const { body, headers, errorStrategy, to, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/contentbody/convert/async/${encodeURIComponent(to)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the asynchronous content body for the corresponding id if the task is complete
  or returns the status of the task.
  
  After the task is completed, the result can be obtained for 5 minutes, or until an identical conversion request is made again,
  with allowCache query param set to false.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  If request specifies 'contentIdContext', 'View' permission for the space, and permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-body/#api-wiki-rest-api-contentbody-convert-async-id-get
  * @param options Request options.
  */
    async getAsyncConvertResult(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/rest/api/contentbody/convert/async/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentBodyMacroGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the body of a macro in storage format, for the given macro ID.
  This includes information like the name of the macro, the body of the macro,
  and any macro parameters. This method is mainly used by Cloud apps.
  
  About the macro ID: When a macro is created in a new version of content,
  Confluence will generate a random ID for it, unless an ID is specified
  (by an app). The macro ID will look similar to this: '50884bd9-0cb8-41d5-98be-f80943c14f96'.
  The ID is then persisted as new versions of content are created, and is
  only modified by Confluence if there are conflicting IDs.
  
  For Forge macros, the value for macro ID is the "local ID" of that particular ADF node.
  This value can be retrieved either client-side by calling view.getContext() and accessing "localId"
  on the resulting object, or server-side by examining the "local-id" parameter node inside the "parameters" node.
  
  Note that there are other attributes named "local-id", but only this particular one is used to store the macro ID.
  
  Example:
  <ac:adf-node type="extension">
    <ac:adf-attribute key="extension-type">com.atlassian.ecosystem</ac:adf-attribute>
    <ac:adf-attribute key="parameters">
        <ac:adf-parameter key="local-id">e9c4aa10-73fa-417c-888d-48c719ae4165</ac:adf-parameter>
    </ac:adf-parameter>
  </ac:adf-node>
  
  Note, to preserve backwards compatibility this resource will also match on
  the hash of the macro body, even if a macro ID is found. This check will
  eventually become redundant, as macro IDs are generated for pages and
  transparently propagate out to all instances.
  
  This backwards compatibility logic does not apply to Forge macros; those
  can only be retrieved by their ID.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content that the macro is in.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---macro-body/#api-wiki-rest-api-content-id-history-version-macro-id-macroid-get
  * @param options Request options.
  */
    async getMacroById(options) {
        const { headers, errorStrategy, id, version, macroId } = options;
        const request = new Request("GET", `/wiki/rest/api/content/${encodeURIComponent(id)}/history/${encodeURIComponent(version)}/macro/id/${encodeURIComponent(macroId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentChildrenGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a map of the direct children of a piece of content. A piece of content
  has different types of child content, depending on its type. These are
  the default parent-child content type relationships:
  
  - `page`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: child content is `comment`, `attachment`
  - `attachment`: child content is `comment`
  - `comment`: child content is `attachment`
  
  Apps can override these default relationships. Apps can also introduce
  new content types that create new parent-child content relationships.
  
  Note, the map will always include all child content types that are valid
  for the content. However, if the content has no instances of a child content
  type, the map will contain an empty array for that child content type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-child-get
  * @param options Request options.
  * @deprecated
  */
    async getChildren(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all children of a given type, for a piece of content.
  A piece of content has different types of child content, depending on its type:
  
  - `page`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: child content is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: child content is `comment`, `attachment`
  - `attachment`: child content is `comment`
  - `comment`: child content is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  Note, this method only returns direct children. To return children at all
  levels, use [Get descendants by type](#api-content-id-descendant-type-get).
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-child-type-get
  * @param options Request options.
  * @deprecated
  */
    async getChildrenByType(options) {
        const { headers, errorStrategy, id, type, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/${encodeURIComponent(type)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentMoveGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Move a page to a new location relative to a target page:
  
  * `before` - move the page under the same parent as the target, before the target in the list of children
  * `after` - move the page under the same parent as the target, after the target in the list of children
  * `append` - move the page to be a child of the target
  
  Caution: This API can move pages to the top level of a space. Top-level pages are difficult to find in the UI
  because they do not show up in the page tree display. To avoid this, never use `before` or `after` positions
  when the `targetId` is a top-level page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-pageid-move-position-targetid-put
  * @param options Request options.
  */
    async movePageToNewLocationRelativeToTargetPage(options) {
        const { headers, errorStrategy, pageId, position, targetId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(pageId)}/move/${encodeURIComponent(position)}/${encodeURIComponent(targetId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentDescendantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a map of the descendants of a piece of content. This is similar
  to [Get content children](#api-content-id-child-get), except that this
  method returns child pages at all levels, rather than just the direct
  child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  The map will always include all descendant types that are valid for the content.
  However, if the content has no instances of a descendant type, the map will
  contain an empty array for that descendant type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-get
  * @param options Request options.
  * @deprecated
  */
    async getDescendants(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/descendant`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all descendants of a given type, for a piece of content. This is
  similar to [Get content children by type](#api-content-id-child-type-get),
  except that this method returns child pages at all levels, rather than just
  the direct child pages.
  
  A piece of content has different types of descendants, depending on its type:
  
  - `page`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `whiteboard`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `database`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `embed`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `folder`: descendant is `page`, `whiteboard`, `database`, `embed`, `folder`, `comment`, `attachment`
  - `blogpost`: descendant is `comment`, `attachment`
  - `attachment`: descendant is `comment`
  - `comment`: descendant is `attachment`
  
  Custom content types that are provided by apps can also be returned.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it
  is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-descendant-type-get
  * @param options Request options.
  * @deprecated
  */
    async getDescendantsByType(options) {
        const { headers, errorStrategy, id, type, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/descendant/${encodeURIComponent(type)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentCopyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Copy page hierarchy allows the copying of an entire hierarchy of pages and their associated properties, permissions and attachments.
   The id path parameter refers to the content id of the page to copy, and the new parent of this copied page is defined using the destinationPageId in the request body.
   The titleOptions object defines the rules of renaming page titles during the copy;
   for example, search and replace can be used in conjunction to rewrite the copied page titles.
  
   Response example:
   <pre><code>
   {
        "id" : "1180606",
        "links" : {
             "status" : "/rest/api/longtask/1180606"
        }
   }
   </code></pre>
   Use the /longtask/<taskId> REST API to get the copy task status.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-pagehierarchy-copy-post
  * @param options Request options.
  */
    async copyPageHierarchy(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/pagehierarchy/copy`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Copies a single page and its associated properties, permissions, attachments, and custom contents.
   The `id` path parameter refers to the content ID of the page to copy. The target of the page to be copied
   is defined using the `destination` in the request body and can be one of the following types.
  
    - `space`: page will be copied to the specified space as a root page on the space
    - `parent_page`: page will be copied as a child of the specified parent page
    - `parent_content`: page will be copied as a child of the specified parent content
    - `existing_page`: page will be copied and replace the specified page
  
  By default, the following objects are expanded: `space`, `history`, `version`.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Add' permission for the space that the content will be copied in and permission to update the content if copying to an `existing_page`.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content---children-and-descendants/#api-wiki-rest-api-content-id-copy-post
  * @param options Request options.
  */
    async copySinglePage(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/copy`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the comments on a piece of content.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space,
  and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-comments/#api-wiki-rest-api-content-id-child-comment-get
  * @param options Request options.
  * @deprecated
  */
    async getComments(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/child/comment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the labels on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-get
  * @param options Request options.
  * @deprecated
  */
    async getLabels(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds labels to a piece of content. Does not modify the existing labels.
  
  Notes:
  
  - Labels can also be added when creating content ([Create content](#api-content-post)).
  - Labels can be updated when updating content ([Update content](#api-content-id-put)).
  This will delete the existing labels and replace them with the labels in
  the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-post
  * @param options Request options.
  */
    async addLabel(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/label`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content](#api-content-id-label-label-delete)
  except that the label name is specified via a query parameter.
  
  Use this method if the label name has "/" characters, as
  [Remove label from content using query parameter](#api-content-id-label-delete)
  does not accept "/" characters for the label name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-delete
  * @param options Request options.
  */
    async removeLabelWithQueryParameter(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a label from a piece of content. Labels can't be deleted from archived content.
  This is similar to [Remove label from content using query parameter](#api-content-id-label-delete)
  except that the label name is specified via a path parameter.
  
  Use this method if the label name does not have "/" characters, as the path
  parameter does not accept "/" characters for security reasons. Otherwise,
  use [Remove label from content using query parameter](#api-content-id-label-delete).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-labels/#api-wiki-rest-api-content-id-label-label-delete
  * @param options Request options.
  */
    async removeLabel(options) {
        const { headers, errorStrategy, id, label } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/label/${encodeURIComponent(label)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the properties for a piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-get
  * @param options Request options.
  * @deprecated
  */
    async getProperties(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/property`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a property for an existing piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  This is the same as [Create content property for key](#api-content-id-property-key-post)
  except that the key is specified in the request body instead of as a
  path parameter.
  
  Content properties can also be added when creating a new piece of content
  by including them in the `metadata.properties` of the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-post
  * @param options Request options.
  * @deprecated
  */
    async createProperty(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/property`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a content property for a piece of content. For more information, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space, and permission to view the content if it is a page.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-get
  * @param options Request options.
  * @deprecated
  */
    async getProperty(options) {
        const { headers, errorStrategy, id, key, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/property/${encodeURIComponent(key)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates an existing content property. This method will also create a new
  property for a piece of content, if the property key does not exist and
  the property version is 1. For more information about content properties, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-put
  * @param options Request options.
  * @deprecated
  */
    async updateProperty(options) {
        const { body, headers, errorStrategy, id, key } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(id)}/property/${encodeURIComponent(key)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a property for an existing piece of content. For more information
  about content properties, see [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  This is the same as [Create content property](#api-content-id-property-post)
  except that the key is specified as a path parameter instead of in the
  request body.
  
  Content properties can also be added when creating a new piece of content
  by including them in the `metadata.properties` of the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-post
  * @param options Request options.
  * @deprecated
  */
    async createPropertyForKey(options) {
        const { body, headers, errorStrategy, id, key } = options;
        const request = new Request("POST", `/wiki/rest/api/content/${encodeURIComponent(id)}/property/${encodeURIComponent(key)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a content property. For more information about content properties, see
  [Confluence entity properties](https://developer.atlassian.com/cloud/confluence/confluence-entity-properties/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-properties/#api-wiki-rest-api-content-id-property-key-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, id, key } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/property/${encodeURIComponent(key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentRestrictionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Group = new ContentRestrictionGroupGroup(implementation, this.getGlobalErrorStrategy);
        this.User = new ContentRestrictionUserGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the restrictions on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-get
  * @param options Request options.
  */
    async getRestrictions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates restrictions for a piece of content. This removes the existing
  restrictions and replaces them with the restrictions in the request.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-put
  * @param options Request options.
  */
    async updateRestrictions(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds restrictions to a piece of content. Note, this does not change any
  existing restrictions on the content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-post
  * @param options Request options.
  */
    async addRestrictions(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes all restrictions (read and update) on a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-delete
  * @param options Request options.
  */
    async deleteRestrictions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns restrictions on a piece of content by operation. This method is
  similar to [Get restrictions](#api-content-id-restriction-get) except that
  the operations are properties of the return object, rather than items in
  a results array.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-get
  * @param options Request options.
  */
    async getRestrictionsByOperation(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the restictions on a piece of content for a given operation (read
  or update).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-get
  * @param options Request options.
  */
    async getRestrictionsForOperation(options) {
        const { headers, errorStrategy, id, operationKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentRestrictionGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether the specified content restriction applies to a group.
  For example, if a page with `id=123` has a `read` restriction for the `123456` group id,
  the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/byGroupId/123456`
  
  Note that a response of `true` does not guarantee that the group can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-get
  * @param options Request options.
  */
    async getGroupStatus(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("GET", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Adds a group to a content restriction by Group Id. That is, grant read or update
  permission to the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-put
  * @param options Request options.
  */
    async addGroup(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("PUT", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-bygroupid-groupid-delete
  * @param options Request options.
  */
    async removeGroup(options) {
        const { headers, errorStrategy, id, operationKey, groupId } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/byGroupId/${encodeURIComponent(groupId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentRestrictionUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether the specified content restriction applies to a user.
  For example, if a page with `id=123` has a `read` restriction for a user with an account ID of
  `384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`, the following request will return `true`:
  
  `/wiki/rest/api/content/123/restriction/byOperation/read/user?accountId=384093:32b4d9w0-f6a5-3535-11a3-9c8c88d10192`
  
  Note that a response of `true` does not guarantee that the user can view the page, as it does not account for
  account-inherited restrictions, space permissions, or even product access. For more
  information, see [Confluence permissions](https://confluence.atlassian.com/x/_AozKw).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-get
  * @param options Request options.
  */
    async getUserStatus(options) {
        const { headers, errorStrategy, id, operationKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user to a content restriction. That is, grant read or update
  permission to the user for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-put
  * @param options Request options.
  */
    async addUser(options) {
        const { headers, errorStrategy, id, operationKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a group from a content restriction. That is, remove read or update
  permission for the group for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to edit the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-restrictions/#api-wiki-rest-api-content-id-restriction-byoperation-operationkey-user-delete
  * @param options Request options.
  */
    async removeUser(options) {
        const { headers, errorStrategy, id, operationKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/restriction/byOperation/${encodeURIComponent(operationKey)}/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentVersionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns the versions for a piece of content in descending order.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-get
  * @param options Request options.
  * @deprecated
  */
    async getVersions(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/version`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Restores a historical version to be the latest version. That is, a new version
  is created with the content of the historical version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-post
  * @param options Request options.
  */
    async restoreVersion(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/version`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a version for a piece of content.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the content. If the content is a blog post, 'View' permission
  for the space is required.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-get
  * @param options Request options.
  * @deprecated
  */
    async getVersion(options) {
        const { headers, errorStrategy, id, versionNumber, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/version/${encodeURIComponent(versionNumber)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a historical version. This does not delete the changes made to the
  content in that version, rather the changes for the deleted version are
  rolled up into the next version. Note, you cannot delete the current version.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to update the content.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-versions/#api-wiki-rest-api-content-id-version-versionnumber-delete
  * @param options Request options.
  */
    async deleteVersion(options) {
        const { headers, errorStrategy, id, versionNumber } = options;
        const request = new Request("DELETE", `/wiki/rest/api/content/${encodeURIComponent(id)}/version/${encodeURIComponent(versionNumber)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WatcherGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Content = new WatcherContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new WatcherLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Space = new WatcherSpaceGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the watches for a page. A user that watches a page will receive
  receive notifications when the page is updated.
  
  If you want to manage watches for a page, use the following `user` methods:
  
  - [Get content watch status for user](#api-user-watch-content-contentId-get)
  - [Add content watch](#api-user-watch-content-contentId-post)
  - [Remove content watch](#api-user-watch-content-contentId-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-child-created-get
  * @param options Request options.
  */
    async getWatchesForPage(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/notification/child-created`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all space watches for the space that the content is in. A user that
  watches a space will receive receive notifications when any content in the
  space is updated.
  
  If you want to manage watches for a space, use the following `user` methods:
  
  - [Get space watch status for user](#api-user-watch-space-spaceKey-get)
  - [Add space watch](#api-user-watch-space-spaceKey-post)
  - [Remove space watch](#api-user-watch-space-spaceKey-delete)
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-content-id-notification-created-get
  * @param options Request options.
  */
    async getWatchesForSpace(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/content/${encodeURIComponent(id)}/notification/created`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a list of watchers of a space
     * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-space-spacekey-watch-get
     * @param options Request options.
     */
    async getSpaceWatchers(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/watch`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WatcherContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a piece of content. Choose the user by doing
  one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a user as a watcher from a piece of content. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-content-contentid-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, contentId, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WatcherLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a label. Choose the user by doing one
  of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a label. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a user as a watcher from a label. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-label-labelname-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, labelName, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/label/${encodeURIComponent(labelName)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WatcherSpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns whether a user is watching a space. Choose the user by
  doing one of the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-get
  * @param options Request options.
  */
    async getWatcherStatus(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher to a space. Choose the user by doing one of the
  following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  Note, you must add the `X-Atlassian-Token: no-check` header when making a
  request, as this operation has XSRF protection.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a user as a watcher from a space. Choose the user by doing one of
  the following:
  
  - Specify a user via a query parameter: Use the `accountId` to identify the user.
  - Do not specify a user: The currently logged-in user will be used.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Confluence Administrator' global permission if specifying a user, otherwise
  permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-content-watches/#api-wiki-rest-api-user-watch-space-spacekey-delete
  * @param options Request options.
  */
    async removeWatcher(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/user/watch/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class DynamicModuleGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all modules registered dynamically by the calling app.
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-get
  * @param options Request options.
  */
    async getModules(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/atlassian-connect/1/app/module/dynamic`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Registers a list of modules. For the list of modules that support dynamic registration, see [Dynamic modules](https://developer.atlassian.com/cloud/confluence/dynamic-modules/).
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-post
  * @param options Request options.
  */
    async registerModules(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/atlassian-connect/1/app/module/dynamic`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Remove all or a list of modules registered by the calling app.
  
  **[Permissions](#permissions) required:** Only Connect apps can make this request.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-dynamic-modules/#api-atlassian-connect-1-app-module-dynamic-delete
  * @param options Request options.
  */
    async removeModules(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/atlassian-connect/1/app/module/dynamic`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class UserGroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Member = new UserGroupMemberGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all user groups. The returned groups are ordered alphabetically in
  ascending order by group name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-get
  * @param options Request options.
  */
    async getUserGroups(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-post
  * @param options Request options.
  */
    async createUserGroup(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/group`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete user group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-delete
  * @param options Request options.
  */
    async deleteUserGroup(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/group/by-id`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a user group for a given group id.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-by-id-get
  * @param options Request options.
  */
    async getUserGroupById(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group/by-id`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroupMemberGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Adds a user as a member in a group represented by its groupId
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-post
  * @param options Request options.
  */
    async addMemberById(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/group/userByGroupId`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Remove user as a member from a group.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  User must be a site admin.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-userbygroupid-delete
  * @param options Request options.
  */
    async removeMemberById(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/group/userByGroupId`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the users that are members of a group.
  
  Use updated Get group API
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-group/#api-wiki-rest-api-group-groupid-membersbygroupid-get
  * @param options Request options.
  */
    async getMembersById(options) {
        const { headers, errorStrategy, groupId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/group/${encodeURIComponent(groupId)}/membersByGroupId`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class InlineTaskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns inline tasks based on the search query.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only tasks
  in contents that the user has permission to view are returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-inline-tasks/#api-wiki-rest-api-inlinetasks-search-get
  * @param options Request options.
  * @deprecated
  */
    async getInlineTasksBasedOnSearchParameters(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/inlinetasks/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns label information and a list of contents associated with the label.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission). Only contents
  that the user is permitted to view is returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-label-info/#api-wiki-rest-api-label-get
  * @param options Request options.
  */
    async getInfo(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LongRunningTaskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns information about all active long-running tasks (e.g. space export),
  such as how long each task has been running and the percentage of each task
  that has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-get
  * @param options Request options.
  */
    async getLongRunningTasks(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/longtask`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns information about an active long-running task (e.g. space export),
  such as how long it has been running and the percentage of the task that
  has completed.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-long-running-task/#api-wiki-rest-api-longtask-id-get
  * @param options Request options.
  */
    async getLongRunningTask(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/wiki/rest/api/longtask/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RelationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all content that the current user
  has an 'ignore' relationship with:
  `GET /wiki/rest/api/relation/ignore/from/user/current/to/content`
  Note, 'ignore' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-get
  * @param options Request options.
  */
    async findTargetEntitiesRelatedToSourceEntity(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find whether a particular type of relationship exists from a source
  entity to a target entity. Note, relationships are one way.
  
  For example, you can use this method to find whether the current user has
  selected a particular page as a favorite (i.e. 'save for later'):
  `GET /wiki/rest/api/relation/favourite/from/user/current/to/content/123`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-get
  * @param options Request options.
  */
    async findRelationshipFromSourceToTarget(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a relationship between two entities (user, space, content). The
  'favourite' relationship is supported by default, but you can use this method
  to create any type of relationship between two entities.
  
  For example, the following method creates a 'sibling' relationship between
  two pieces of content:
  `PUT /wiki/rest/api/relation/sibling/from/content/123/to/content/456`
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-put
  * @param options Request options.
  */
    async createRelationship(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a relationship between two entities (user, space, content).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  For favourite relationships, the current user can only delete their own
  favourite relationships. A space administrator can delete favourite
  relationships for any user.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-from-sourcetype-sourcekey-to-targettype-targetkey-delete
  * @param options Request options.
  */
    async deleteRelationship(options) {
        const { headers, errorStrategy, relationName, sourceType, sourceKey, targetType, targetKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/from/${encodeURIComponent(sourceType)}/${encodeURIComponent(sourceKey)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns all target entities that have a particular relationship to the
  source entity. Note, relationships are one way.
  
  For example, the following method finds all users that have a 'collaborator'
  relationship to a piece of content with an ID of '1234':
  `GET /wiki/rest/api/relation/collaborator/to/content/1234/from/user`
  Note, 'collaborator' is an example custom relationship type.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view both the target entity and source entity.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-relation/#api-wiki-rest-api-relation-relationname-to-targettype-targetkey-from-sourcetype-get
  * @param options Request options.
  */
    async findSourceEntitiesRelatedToTargetEntity(options) {
        const { headers, errorStrategy, relationName, sourceType, targetType, targetKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/relation/${encodeURIComponent(relationName)}/to/${encodeURIComponent(targetType)}/${encodeURIComponent(targetKey)}/from/${encodeURIComponent(sourceType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Searches for content using the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  **Note that CQL input queries submitted through the `/wiki/rest/api/search` endpoint no longer support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.**
  See this [deprecation notice](https://developer.atlassian.com/cloud/confluence/deprecation-notice-search-api/) for more details.
  
  Example initial call:
  ```
  /wiki/rest/api/search?cql=type=page&limit=25
  ```
  
  Example response:
  ```
  {
    "results": [
      { ... },
      { ... },
      ...
      { ... }
    ],
    "limit": 25,
    "size": 25,
    ...
    "_links": {
      "base": "<url>",
      "context": "<url>",
      "next": "/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg",
      "self": "<url>"
    }
  }
  ```
  
  When additional results are available, returns `next` and `prev` URLs to retrieve them in subsequent calls. The URLs each contain a cursor that points to the appropriate set of results. Use `limit` to specify the number of results returned in each call.
  
  Example subsequent call (taken from example response):
  ```
  /wiki/rest/api/search?cql=type=page&limit=25&cursor=raNDoMsTRiNg
  ```
  The response to this will have a `prev` URL similar to the `next` in the example response.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to view the entities. Note, only entities that the user has
  permission to view will be returned.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-get
  * @param options Request options.
  */
    async searchContent(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Searches for users using user-specific queries from the
  [Confluence Query Language (CQL)](https://developer.atlassian.com/cloud/confluence/advanced-searching-using-cql/).
  
  Note that CQL input queries submitted through the `/wiki/rest/api/search/user` endpoint only support user-specific fields like `user`, `user.fullname`, `user.accountid`, and `user.userkey`.
  
  Note that some user fields may be set to null depending on the user's privacy settings.
  These are: email, profilePicture, displayName, and timeZone.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-search/#api-wiki-rest-api-search-user-get
  * @param options Request options.
  */
    async searchUsers(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/search/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SettingGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the look and feel settings for the site or a single space. This
  includes attributes such as the color scheme, padding, and border radius.
  
  The look and feel settings for a space can be inherited from the global
  look and feel settings or provided by a theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-get
  * @param options Request options.
  */
    async getLookAndFeelSettings(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/settings/lookandfeel`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the look and feel settings for the site or for a single space.
  If custom settings exist, they are updated. If no custom settings exist,
  then a set of custom settings is created.
  
  Note, if a theme is selected for a space, the space look and feel settings
  are provided by the theme and cannot be overridden.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-post
  * @param options Request options.
  */
    async updateLookAndFeelSettings(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/wiki/rest/api/settings/lookandfeel/custom`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Resets the custom look and feel settings for the site or a single space.
  This changes the values of the custom settings to be the same as the
  default settings. It does not change which settings (default or custom)
  are selected. Note, the default space settings are inherited from the
  current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-custom-delete
  * @param options Request options.
  */
    async resetLookAndFeelSettings(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("DELETE", constructUrl(`/wiki/rest/api/settings/lookandfeel/custom`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Sets the look and feel settings to either the default settings or the
  custom settings, for the site or a single space. Note, the default
  space settings are inherited from the current global settings.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-lookandfeel-selected-put
  * @param options Request options.
  * @deprecated
  */
    async setLookAndFeelSettings(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/wiki/rest/api/settings/lookandfeel/selected`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the system information for the Confluence Cloud tenant. This
  information is used by Atlassian.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-settings/#api-wiki-rest-api-settings-systeminfo-get
  * @param options Request options.
  */
    async getSystemInfo(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/wiki/rest/api/settings/systemInfo`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Private = new SpacePrivateGroup(implementation, this.getGlobalErrorStrategy);
        this.Content = new SpaceContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new SpacePropertyGroup(implementation, this.getGlobalErrorStrategy);
        this.Setting = new SpaceSettingGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all spaces. The returned spaces are ordered alphabetically in
  ascending order by space key.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  Note, the returned list will only contain spaces that the current user
  has permission to view.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-get
  * @param options Request options.
  * @deprecated
  */
    async getSpaces(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new space. Note, currently you cannot set space labels when
  creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-post
  * @param options Request options.
  */
    async createSpace(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/space`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a space. This includes information like the name, description,
  and permissions, but not the content in the space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-get
  * @param options Request options.
  * @deprecated
  */
    async getSpace(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the name, description, or homepage of a space.
  
  -   For security reasons, permissions cannot be updated via the API and
  must be changed via the user interface instead.
  -   Currently you cannot set space labels when updating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-put
  * @param options Request options.
  */
    async updateSpace(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Permanently deletes a space without sending it to the trash. Note, the space will be deleted in a long running task.
  Therefore, the space may not be deleted yet when this method has
  returned. Clients should poll the status link that is returned in the
  response until the task completes.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-delete
  * @param options Request options.
  */
    async deleteSpace(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("DELETE", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpacePrivateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a new space that is only visible to the creator. This method is
  the same as the [Create space](#api-space-post) method with permissions
  set to the current user only. Note, currently you cannot set space
  labels when creating a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Create Space(s)' global permission.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-private-post
  * @param options Request options.
  */
    async createSpace(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/space/_private`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpaceContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content in a space. The returned content is grouped by type
  (pages then blogposts), then ordered by content ID in ascending order.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space. Note, the returned list will only
  contain content that the current user has permission to view.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-content-get
  * @param options Request options.
  * @deprecated
  */
    async getContent(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/content`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all content of a given type, in a space. The returned content is
  ordered by content ID in ascending order.
  
  If the expand query parameter is used with the `body.export_view` and/or `body.styled_view` properties, then the query limit parameter will be restricted to a maximum value of 25.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space. Note, the returned list will only
  contain content that the current user has permission to view.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space/#api-wiki-rest-api-space-spacekey-content-type-get
  * @param options Request options.
  * @deprecated
  */
    async getContentByType(options) {
        const { headers, errorStrategy, spaceKey, type, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/content/${encodeURIComponent(type)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpacePropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns all properties for the given space. Space properties are a key-value storage associated with a space.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-get
  * @param options Request options.
  * @deprecated
  */
    async getProperties(options) {
        const { headers, errorStrategy, spaceKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-post
  * @param options Request options.
  * @deprecated
  */
    async createProperty(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("POST", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Returns a space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-get
  * @param options Request options.
  * @deprecated
  */
    async getProperty(options) {
        const { headers, errorStrategy, spaceKey, key, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property/${encodeURIComponent(key)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Updates a space property. Note, you cannot update the key of a space
  property, only the value.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-put
  * @param options Request options.
  * @deprecated
  */
    async updateProperty(options) {
        const { body, headers, errorStrategy, spaceKey, key } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property/${encodeURIComponent(key)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Creates a new space property. This is the same as `POST
  /wiki/rest/api/space/{spaceKey}/property` but the key for the property is passed as a
  path parameter, rather than in the request body.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-post
  * @param options Request options.
  * @deprecated
  */
    async createPropertyForKey(options) {
        const { body, headers, errorStrategy, spaceKey, key } = options;
        const request = new Request("POST", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property/${encodeURIComponent(key)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deprecated, use [Confluence's v2 API](https://developer.atlassian.com/cloud/confluence/rest/v2/intro/).
  
  Deletes a space property.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**:
  ‘Admin’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-properties/#api-wiki-rest-api-space-spacekey-property-key-delete
  * @param options Request options.
  * @deprecated
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, spaceKey, key } = options;
        const request = new Request("DELETE", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/property/${encodeURIComponent(key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class SpaceSettingGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the settings of a space. Currently only the
  `routeOverrideEnabled` setting can be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-get
  * @param options Request options.
  */
    async getSettings(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("GET", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/settings`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the settings for a space. Currently only the
  `routeOverrideEnabled` setting can be updated.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-space-settings/#api-wiki-rest-api-space-spacekey-settings-put
  * @param options Request options.
  */
    async updateSettings(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/settings`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TemplateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Updates a content template. Note, blueprint templates cannot be updated
  via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to update a space template or 'Confluence Administrator'
  global permission to update a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-put
  * @param options Request options.
  */
    async updateContentTemplate(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/wiki/rest/api/template`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space to create a space template or 'Confluence Administrator'
  global permission to create a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-post
  * @param options Request options.
  */
    async createContentTemplate(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/wiki/rest/api/template`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all templates provided by blueprints. Use this method to retrieve
  all global blueprint templates or all blueprint templates in a space.
  
  Note, all global blueprints are inherited by each space. Space blueprints
  can be customised without affecting the global blueprints.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view blueprints for the space and permission
  to access the Confluence site ('Can use' global permission) to view global blueprints.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-blueprint-get
  * @param options Request options.
  */
    async getBlueprintTemplates(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/template/blueprint`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all content templates. Use this method to retrieve all global
  content templates or all content templates in a space.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-page-get
  * @param options Request options.
  */
    async getContentTemplates(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/template/page`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a content template. This includes information about template,
  like the name, the space or blueprint that the template is in, the body
  of the template, and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'View' permission for the space to view space templates and permission to
  access the Confluence site ('Can use' global permission) to view global templates.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-get
  * @param options Request options.
  */
    async getContentTemplate(options) {
        const { headers, errorStrategy, contentTemplateId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/template/${encodeURIComponent(contentTemplateId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a template. This results in different actions depending on the
  type of template:
  
  - If the template is a content template, it is deleted.
  - If the template is a modified space-level blueprint template, it reverts
  to the template inherited from the global-level blueprint template.
  - If the template is a modified global-level blueprint template, it reverts
  to the default global-level blueprint template.
  
   Note, unmodified blueprint templates cannot be deleted.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
          'Admin' permission for the space to delete a space template or 'Confluence Administrator'
          global permission to delete a global template.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-template/#api-wiki-rest-api-template-contenttemplateid-delete
  * @param options Request options.
  */
    async removeTemplate(options) {
        const { headers, errorStrategy, contentTemplateId } = options;
        const request = new Request("DELETE", `/wiki/rest/api/template/${encodeURIComponent(contentTemplateId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ThemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all themes, not including the default theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-get
  * @param options Request options.
  */
    async getThemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/settings/theme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the globally assigned theme.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-selected-get
  * @param options Request options.
  */
    async getGlobalTheme(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/wiki/rest/api/settings/theme/selected`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a theme. This includes information about the theme name,
  description, and icon.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: None
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-settings-theme-themekey-get
  * @param options Request options.
  */
    async getTheme(options) {
        const { headers, errorStrategy, themeKey } = options;
        const request = new Request("GET", `/wiki/rest/api/settings/theme/${encodeURIComponent(themeKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the theme selected for a space, if one is set. If no space
  theme is set, this means that the space is inheriting the global look
  and feel settings.
  
  **[Permissions required](https://confluence.atlassian.com/x/_AozKw)**: ‘View’ permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-get
  * @param options Request options.
  */
    async getSpaceTheme(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("GET", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the theme for a space. Note, if you want to reset the space theme to
  the default Confluence theme, use the 'Reset space theme' method instead
  of this method.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-put
  * @param options Request options.
  */
    async setSpaceTheme(options) {
        const { body, headers, errorStrategy, spaceKey } = options;
        const request = new Request("PUT", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Resets the space theme. This means that the space will inherit the
  global look and feel settings
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  'Admin' permission for the space.
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-themes/#api-wiki-rest-api-space-spacekey-theme-delete
  * @param options Request options.
  */
    async resetSpaceTheme(options) {
        const { headers, errorStrategy, spaceKey } = options;
        const request = new Request("DELETE", `/wiki/rest/api/space/${encodeURIComponent(spaceKey)}/theme`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a user. This includes information about the user, such as the
  display name, account ID, profile picture, and more. The information returned may be
  restricted by the user's profile visibility settings.
  
  **Note:** to add, edit, or delete users in your organization, see the
  [user management REST API](/cloud/admin/user-management/about/).
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-get
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns information about how anonymous users are represented, like the
  profile picture and display name.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-anonymous-get
  * @param options Request options.
  */
    async getAnonymousUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/anonymous`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the currently logged-in user. This includes information about
  the user, like the display name, userKey, account ID, profile picture,
  and more.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-current-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/current`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the groups that a user is a member of.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-memberof-get
  * @param options Request options.
  */
    async getGroupsWhereUserMember(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/memberof`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns user details for the ids provided in the request.
  Currently this API returns a maximum of 100 results.
  If more than 100 account ids are passed in, then the first 100 will be returned.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-bulk-get
  * @param options Request options.
  */
    async getUsersWithIds(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/bulk`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-get
  * @param options Request options.
  */
    async getUserEmail(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/email`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a user's email address regardless of the user’s profile visibility settings. For Connect apps, this API is only available to apps approved by
  Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
  For Forge apps, this API only supports access via asApp() requests.
  
  Any accounts which are not available will not be included in the result.
  
  **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**:
  Permission to access the Confluence site ('Can use' global permission).
  * Documentation: https://developer.atlassian.com/cloud/confluence/rest/v1/api-group-users/#api-wiki-rest-api-user-email-bulk-get
  * @param options Request options.
  */
    async getUserEmails(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/wiki/rest/api/user/email/bulk`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map